@@ -5,12 +5,15 @@
    It may be used under the terms of the GNU General Public License. */
 
 #import "HBController.h"
+#import "HBAppDelegate.h"
 #import "HBFocusRingView.h"
 #import "HBToolbarBadgedItem.h"
 #import "HBQueueController.h"
 #import "HBTitleSelectionController.h"
 #import "NSWindow+HBAdditions.h"
 
+#import "HBQueue.h"
+
 #import "HBPresetsManager.h"
 #import "HBPreset.h"
 #import "HBMutablePreset.h"
@@ -32,11 +35,13 @@
 #import "HBRenamePresetController.h"
 
 #import "HBAutoNamer.h"
+#import "HBJob+HBAdditions.h"
+#import "HBAttributedStringAdditions.h"
 
-@import HandBrakeKit;
+#import "HBPreferencesKeys.h"
 
 static void *HBControllerScanCoreContext = &HBControllerScanCoreContext;
-static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
+static void *HBControllerLogLevelContext = &HBControllerLogLevelContext;
 
 @interface HBController () <HBPresetsViewControllerDelegate, HBTitleSelectionDelegate, NSDraggingDestination, NSPopoverDelegate>
 {
@@ -79,7 +84,6 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
     // Bottom
     IBOutlet NSTextField         * fStatusField;
     IBOutlet NSProgressIndicator * fRipIndicator;
-    BOOL                           fRipIndicatorShown;
 
     // User Preset
     HBPresetsManager             * presetManager;
@@ -121,8 +125,11 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
 /// The HBCore used for scanning.
 @property (nonatomic, strong) HBCore *core;
 
-/// The queue controller.
-@property (nonatomic, strong) HBQueueController *queue;
+/// The app delegate.
+@property (nonatomic, strong) HBAppDelegate *delegate;
+
+/// The queue.
+@property (nonatomic, weak) HBQueue *queue;
 
 /// Whether the window is visible or occluded,
 /// useful to avoid updating the UI needlessly
@@ -145,7 +152,7 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
 
 @interface HBController (TouchBar) <NSTouchBarProvider, NSTouchBarDelegate>
 - (void)_touchBar_updateButtonsStateForScanCore:(HBState)state;
-- (void)_touchBar_updateButtonsStateForQueueCore:(HBState)state;
+- (void)_touchBar_updateQueueButtonsState;
 - (void)_touchBar_validateUserInterfaceItems;
 @end
 
@@ -154,21 +161,21 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
 
 @implementation HBController
 
-- (instancetype)initWithQueue:(HBQueueController *)queueController presetsManager:(HBPresetsManager *)manager;
+- (instancetype)initWithDelegate:(HBAppDelegate *)delegate queue:(HBQueue *)queue presetsManager:(HBPresetsManager *)manager
 {
     self = [super initWithWindowNibName:@"MainWindow"];
     if (self)
     {
         // Init libhb
-        int loggingLevel = [[[NSUserDefaults standardUserDefaults] objectForKey:@"LoggingLevel"] intValue];
+        NSInteger loggingLevel = [NSUserDefaults.standardUserDefaults integerForKey:HBLoggingLevel];
         _core = [[HBCore alloc] initWithLogLevel:loggingLevel name:@"ScanCore"];
 
         // Inits the controllers
         fPreviewController = [[HBPreviewController alloc] init];
         fPreviewController.documentController = self;
 
-        _queue = queueController;
-        _queue.controller = self;
+        _delegate = delegate;
+        _queue = queue;
 
         presetManager = manager;
         _currentPreset = manager.defaultPreset;
@@ -180,16 +187,16 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
 
         // Check to see if the last destination has been set, use if so, if not, use Movies
 #ifdef __SANDBOX_ENABLED__
-        NSData *bookmark = [[NSUserDefaults standardUserDefaults] objectForKey:@"HBLastDestinationDirectoryBookmark"];
+        NSData *bookmark = [NSUserDefaults.standardUserDefaults objectForKey:HBLastDestinationDirectoryBookmark];
         if (bookmark)
         {
             _currentDestination = [HBUtilities URLFromBookmark:bookmark];
         }
 #else
-        _currentDestination = [[NSUserDefaults standardUserDefaults] URLForKey:@"HBLastDestinationDirectoryURL"];
+        _currentDestination = [NSUserDefaults.standardUserDefaults URLForKey:HBLastDestinationDirectoryURL];
 #endif
 
-        if (!_currentDestination)
+        if (!_currentDestination || [[NSFileManager defaultManager] fileExistsAtPath:_currentDestination.path isDirectory:nil] == NO)
         {
             _currentDestination = [NSURL fileURLWithPath:[NSSearchPathForDirectoriesInDomains(NSMoviesDirectory, NSUserDomainMask, YES) firstObject]
                                              isDirectory:YES];
@@ -203,22 +210,23 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
     return self;
 }
 
-- (void)dealloc
-{
-    [[NSNotificationCenter defaultCenter] removeObserver:self];
-}
-
 - (void)windowDidLoad
 {
+    if (@available (macOS 10.12, *))
+    {
+        self.window.tabbingMode = NSWindowTabbingModeDisallowed;
+    }
+
     [self enableUI:NO];
 
     // Bottom
+    fStatusField.font = [NSFont monospacedDigitSystemFontOfSize:NSFont.smallSystemFontSize weight:NSFontWeightRegular];
     fRipIndicator.hidden = YES;
     [self updateProgress];
 
     // Register HBController's Window as a receiver for files/folders drag & drop operations
-    [self.window registerForDraggedTypes:@[NSFilenamesPboardType]];
-    [fMainTabView registerForDraggedTypes:@[NSFilenamesPboardType]];
+    [self.window registerForDraggedTypes:@[(NSString *)kUTTypeFileURL]];
+    [fMainTabView registerForDraggedTypes:@[(NSString *)kUTTypeFileURL]];
 
     fPresetsView = [[HBPresetsViewController alloc] initWithPresetManager:presetManager];
     fPresetsView.delegate = self;
@@ -227,7 +235,7 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
     self.presetsPopover = [[NSPopover alloc] init];
 
     self.presetsPopover.contentViewController = fPresetsView;
-    self.presetsPopover.contentSize = NSMakeSize(280, 580);
+    self.presetsPopover.contentSize = NSMakeSize(294, 580);
     self.presetsPopover.animates = YES;
 
     // AppKit will close the popover when the user interacts with a user interface element outside the popover.
@@ -265,24 +273,61 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
     fFiltersViewController = [[HBFiltersViewController alloc] init];
     [fFiltersTab setView:[fFiltersViewController view]];
 
+    // Add the observers
+
     [self.core addObserver:self forKeyPath:@"state"
                    options:NSKeyValueObservingOptionNew | NSKeyValueObservingOptionInitial
                    context:HBControllerScanCoreContext];
 
-    [self.queue.core addObserver:self forKeyPath:@"state"
-                   options:NSKeyValueObservingOptionNew | NSKeyValueObservingOptionInitial
-                   context:HBControllerQueueCoreContext];
+    [NSNotificationCenter.defaultCenter addObserverForName:HBQueueDidStartNotification object:_queue queue:NSOperationQueue.mainQueue usingBlock:^(NSNotification * _Nonnull note) {
+        self.bottomConstrain.animator.constant = 0;
+        self->fRipIndicator.hidden = NO;
+    }];
 
-    [self.queue addObserver:self forKeyPath:@"pendingItemsCount"
-              options:NSKeyValueObservingOptionNew | NSKeyValueObservingOptionInitial
-              context:HBControllerQueueCoreContext];
+    [NSNotificationCenter.defaultCenter addObserverForName:HBQueueDidCompleteNotification object:_queue queue:NSOperationQueue.mainQueue usingBlock:^(NSNotification * _Nonnull note) {
+        self.bottomConstrain.animator.constant = -WINDOW_HEIGHT_OFFSET;
+        self->fRipIndicator.hidden = YES;
+    }];
 
+    [NSNotificationCenter.defaultCenter addObserverForName:HBQueueProgressNotification object:_queue queue:NSOperationQueue.mainQueue usingBlock:^(NSNotification * _Nonnull note) {
+        HBQueueItem *item = self.queue.currentItem;
+        NSString *info;
+        if (item)
+        {
+            info = [NSString stringWithFormat:NSLocalizedString(@"Encoding %@\n%@", @""),
+                          self.queue.currentItem.outputFileName,
+                          note.userInfo[HBQueueProgressNotificationInfoKey]];
+        }
+        else
+        {
+            info = note.userInfo[HBQueueProgressNotificationInfoKey];
+        }
+        self.progressInfo = info;
+        self.progress = [note.userInfo[HBQueueProgressNotificationPercentKey] doubleValue];
+
+        if (self->_visible)
+        {
+            [self updateProgress];
+        }
+    }];
+
+    [NSNotificationCenter.defaultCenter addObserverForName:HBQueueDidChangeStateNotification object:_queue queue:NSOperationQueue.mainQueue usingBlock:^(NSNotification * _Nonnull note) {
+        [self updateQueueUI];
+    }];
+
+    [self updateQueueUI];
+
+    // Presets menu
     self.presetsMenuBuilder = [[HBPresetsMenuBuilder alloc] initWithMenu:self.presetsPopup.menu
                                                                   action:@selector(selectPresetFromMenu:)
                                                                     size:[NSFont smallSystemFontSize]
                                                           presetsManager:presetManager];
     [self.presetsMenuBuilder build];
 
+    // Log level
+    [NSUserDefaultsController.sharedUserDefaultsController addObserver:self forKeyPath:@"values.LoggingLevel"
+                                                               options:0 context:HBControllerLogLevelContext];
+
     self.bottomConstrain.constant = -WINDOW_HEIGHT_OFFSET_INIT;
 
     [self.window recalculateKeyViewLoop];
@@ -341,18 +386,9 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
             [self _touchBar_validateUserInterfaceItems];
         }
     }
-    else if (context == HBControllerQueueCoreContext)
+    else if (context == HBControllerLogLevelContext)
     {
-        HBState state = self.queue.core.state;
-        [self updateToolbarButtonsStateForQueueCore:state];
-        [self.window.toolbar validateVisibleItems];
-        if (@available(macOS 10.12.2, *))
-        {
-            [self _touchBar_updateButtonsStateForQueueCore:state];
-            [self _touchBar_validateUserInterfaceItems];
-        }
-        NSUInteger count = self.queue.pendingItemsCount;
-        self.showQueueToolbarItem.badgeValue = count ? @(count).stringValue : nil;
+        self.core.logLevel = [NSUserDefaults.standardUserDefaults integerForKey:HBLoggingLevel];
     }
     else
     {
@@ -360,6 +396,19 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
     }
 }
 
+- (void)updateQueueUI
+{
+    [self updateToolbarButtonsState];
+    [self.window.toolbar validateVisibleItems];
+    if (@available(macOS 10.12.2, *))
+    {
+        [self _touchBar_updateQueueButtonsState];
+        [self _touchBar_validateUserInterfaceItems];
+    }
+    NSUInteger count = self.queue.pendingItemsCount;
+    self.showQueueToolbarItem.badgeValue = count ? @(count).stringValue : @"";
+}
+
 - (void)updateToolbarButtonsStateForScanCore:(HBState)state
 {
     if (state == HBStateIdle)
@@ -376,9 +425,9 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
     }
 }
 
-- (void)updateToolbarButtonsStateForQueueCore:(HBState)state
+- (void)updateToolbarButtonsState
 {
-    if (state == HBStatePaused)
+    if (self.queue.canResume)
     {
         _pauseToolbarItem.image = [NSImage imageNamed: @"encode"];
         _pauseToolbarItem.label = NSLocalizedString(@"Resume", @"Toolbar Pause Item");
@@ -391,7 +440,7 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
         _pauseToolbarItem.toolTip = NSLocalizedString(@"Pause Encoding", @"Toolbar Pause Item");
 
     }
-    if (state == HBStateScanning || state == HBStateWorking || state == HBStateSearching || state == HBStateMuxing || state == HBStatePaused)
+    if (self.queue.isEncoding)
     {
         _ripToolbarItem.image = [NSImage imageNamed:@"stopencode"];
         _ripToolbarItem.label = NSLocalizedString(@"Stop", @"Toolbar Start/Stop Item");
@@ -401,7 +450,7 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
     {
         _ripToolbarItem.image = [NSImage imageNamed: @"encode"];
         _ripToolbarItem.label = _queue.pendingItemsCount > 0 ? NSLocalizedString(@"Start Queue", @"Toolbar Start/Stop Item") :  NSLocalizedString(@"Start", @"Toolbar Start/Stop Item");
-        _pauseToolbarItem.toolTip = NSLocalizedString(@"Start Encoding", @"Toolbar Start/Stop Item");
+        _ripToolbarItem.toolTip = NSLocalizedString(@"Start Encoding", @"Toolbar Start/Stop Item");
     }
 }
 
@@ -437,7 +486,7 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
         {
             return YES;
         }
-        if (action == @selector(rip:) || action == @selector(addToQueue:))
+        if (action == @selector(toggleStartCancel:) || action == @selector(addToQueue:))
         {
             return NO;
         }
@@ -447,30 +496,20 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
         return YES;
     }
 
-    HBState queueState = _queue.core.state;
-
-    if (action == @selector(rip:))
+    if (action == @selector(toggleStartCancel:))
     {
-        if (queueState == HBStateScanning || queueState == HBStateWorking || queueState == HBStateSearching ||
-            queueState == HBStateMuxing || queueState == HBStatePaused)
+        if (self.queue.isEncoding)
         {
             return YES;
         }
         else
         {
-            return (self.job != nil || _queue.pendingItemsCount > 0);
+            return (self.job != nil || self.queue.canEncode);
         }
     }
 
-    if (action == @selector(pause:)) {
-        if (queueState == HBStatePaused)
-        {
-            return YES;
-        }
-        else
-        {
-            return (queueState == HBStateWorking || queueState == HBStateMuxing);
-        }
+    if (action == @selector(togglePauseResume:)) {
+        return self.queue.canPause || self.queue.canResume;
     }
 
     if (action == @selector(addToQueue:))
@@ -499,13 +538,13 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
     {
         return self.window.attachedSheet == nil;
     }
-    if (action == @selector(pause:))
+    if (action == @selector(togglePauseResume:))
     {
-        return [_queue validateMenuItem:menuItem];
+        return [self.delegate validateMenuItem:menuItem];
     }
-    if (action == @selector(rip:))
+    if (action == @selector(toggleStartCancel:))
     {
-        BOOL result = [_queue validateMenuItem:menuItem];
+        BOOL result = [self.delegate validateMenuItem:menuItem];
 
         if ([menuItem.title isEqualToString:NSLocalizedString(@"Start Encoding", @"Menu Start/Stop Item")])
         {
@@ -531,11 +570,11 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
     {
         if ([menuItem.representedObject isEqualTo:self.currentPreset] && self.edited == NO)
         {
-            menuItem.state = NSOnState;
+            menuItem.state = NSControlStateValueOn;
         }
         else
         {
-            menuItem.state = NSOffState;
+            menuItem.state = NSControlStateValueOff;
         }
         return (self.job != nil);
     }
@@ -563,9 +602,9 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
 {
     if (self.core.state != HBStateScanning && !self.job)
     {
-        if ([[NSUserDefaults standardUserDefaults] boolForKey:@"HBShowOpenPanelAtLaunch"])
+        if ([NSUserDefaults.standardUserDefaults boolForKey:HBShowOpenPanelAtLaunch])
         {
-            [self browseSources:nil];
+            [self browseSources:self];
         }
     }
 }
@@ -606,7 +645,7 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
     // Check if we can scan the source and if there is any warning.
     BOOL canScan = [self.core canScan:mediaURL error:&outError];
 
-    // Notify the user that we don't support removal of copy proteciton.
+    // Notify the user that we don't support removal of copy protection.
     if (canScan && [outError code] == 101 && !self.suppressCopyProtectionWarning)
     {
         self.suppressCopyProtectionWarning = YES;
@@ -625,12 +664,12 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
 
     if (canScan)
     {
-        int hb_num_previews = [[[NSUserDefaults standardUserDefaults] objectForKey:@"PreviewsNumber"] intValue];
-        int min_title_duration_seconds = [[[NSUserDefaults standardUserDefaults] objectForKey:@"MinTitleScanSeconds"] intValue];
+        NSUInteger hb_num_previews = [NSUserDefaults.standardUserDefaults integerForKey:HBPreviewsNumber];
+        NSUInteger min_title_duration_seconds = [NSUserDefaults.standardUserDefaults integerForKey:HBMinTitleScanSeconds];
 
         [self.core scanURL:mediaURL
                 titleIndex:index
-                  previews:hb_num_previews minDuration:min_title_duration_seconds
+                  previews:hb_num_previews minDuration:min_title_duration_seconds keepPreviews:YES
            progressHandler:^(HBState state, HBProgress progress, NSString *info)
          {
              self->fSrcDVD2Field.stringValue = info;
@@ -661,13 +700,13 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
              }
 
              // Set the last searched source directory in the prefs here
-             if ([[NSWorkspace sharedWorkspace] isFilePackageAtPath:mediaURL.URLByDeletingLastPathComponent.path])
+             if ([NSWorkspace.sharedWorkspace isFilePackageAtPath:mediaURL.URLByDeletingLastPathComponent.path])
              {
-                 [[NSUserDefaults standardUserDefaults] setURL:mediaURL.URLByDeletingLastPathComponent.URLByDeletingLastPathComponent forKey:@"HBLastSourceDirectoryURL"];
+                 [NSUserDefaults.standardUserDefaults setURL:mediaURL.URLByDeletingLastPathComponent.URLByDeletingLastPathComponent forKey:HBLastSourceDirectoryURL];
              }
              else
              {
-                 [[NSUserDefaults standardUserDefaults] setURL:mediaURL.URLByDeletingLastPathComponent forKey:@"HBLastSourceDirectoryURL"];
+                 [NSUserDefaults.standardUserDefaults setURL:mediaURL.URLByDeletingLastPathComponent forKey:HBLastSourceDirectoryURL];
              }
 
              completionHandler(self.core.titles);
@@ -772,9 +811,9 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
 
     // If the source is not a stream, and autonaming is disabled,
     // keep the existing file name.
-    if (self.job.outputFileName.length == 0 || title.isStream || [[NSUserDefaults standardUserDefaults] boolForKey:@"DefaultAutoNaming"])
+    if (self.job.outputFileName.length == 0 || title.isStream || [NSUserDefaults.standardUserDefaults boolForKey:HBDefaultAutoNaming])
     {
-        job.outputFileName = [HBUtilities defaultNameForJob:job];
+        job.outputFileName = job.defaultName;
     }
     else
     {
@@ -788,10 +827,11 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
 {
     if (self.job)
     {
-        [[NSNotificationCenter defaultCenter] removeObserver:self name:HBContainerChangedNotification object:_job];
-        [[NSNotificationCenter defaultCenter] removeObserver:self name:HBPictureChangedNotification object:_job.picture];
-        [[NSNotificationCenter defaultCenter] removeObserver:self name:HBFiltersChangedNotification object:_job.filters];
-        [[NSNotificationCenter defaultCenter] removeObserver:self name:HBVideoChangedNotification object:_job.video];
+        NSNotificationCenter *center = NSNotificationCenter.defaultCenter;
+        [center removeObserver:self name:HBContainerChangedNotification object:_job];
+        [center removeObserver:self name:HBPictureChangedNotification object:_job.picture];
+        [center removeObserver:self name:HBFiltersChangedNotification object:_job.filters];
+        [center removeObserver:self name:HBVideoChangedNotification object:_job.video];
         self.autoNamer = nil;
     }
 }
@@ -805,10 +845,11 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
 {
     if (self.job)
     {
-        [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(formatChanged:) name:HBContainerChangedNotification object:_job];
-        [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(customSettingUsed) name:HBPictureChangedNotification object:_job.picture];
-        [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(customSettingUsed) name:HBFiltersChangedNotification object:_job.filters];
-        [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(customSettingUsed) name:HBVideoChangedNotification object:_job.video];
+        NSNotificationCenter *center = NSNotificationCenter.defaultCenter;
+        [center addObserver:self selector:@selector(formatChanged:) name:HBContainerChangedNotification object:_job];
+        [center addObserver:self selector:@selector(customSettingUsed) name:HBPictureChangedNotification object:_job.picture];
+        [center addObserver:self selector:@selector(customSettingUsed) name:HBFiltersChangedNotification object:_job.filters];
+        [center addObserver:self selector:@selector(customSettingUsed) name:HBVideoChangedNotification object:_job.video];
         self.autoNamer = [[HBAutoNamer alloc] initWithJob:self.job];
     }
 }
@@ -887,9 +928,9 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
     [panel setCanChooseDirectories:YES];
 
     NSURL *sourceDirectory;
-	if ([[NSUserDefaults standardUserDefaults] URLForKey:@"HBLastSourceDirectoryURL"])
+	if ([NSUserDefaults.standardUserDefaults URLForKey:HBLastSourceDirectoryURL])
 	{
-		sourceDirectory = [[NSUserDefaults standardUserDefaults] URLForKey:@"HBLastSourceDirectoryURL"];
+		sourceDirectory = [NSUserDefaults.standardUserDefaults URLForKey:HBLastSourceDirectoryURL];
 	}
 	else
 	{
@@ -897,13 +938,9 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
                                                        isDirectory:YES];
 	}
 
-    [panel setDirectoryURL:sourceDirectory];
-    [panel setAccessoryView:self.openTitleView];
-
-    if ([panel respondsToSelector:@selector(isAccessoryViewDisclosed)])
-    {
-        panel.accessoryViewDisclosed = YES;
-    }
+    panel.directoryURL = sourceDirectory;
+    panel.accessoryView = self.openTitleView;
+    panel.accessoryViewDisclosed = YES;
 
     [panel beginSheetModalForWindow:self.window completionHandler: ^(NSInteger result)
     {
@@ -939,10 +976,10 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
              self.currentDestination = panel.URL;
 
              // Save this path to the prefs so that on next browse destination window it opens there
-             [[NSUserDefaults standardUserDefaults] setObject:[HBUtilities bookmarkFromURL:panel.URL]
-                                                       forKey:@"HBLastDestinationDirectoryBookmark"];
-             [[NSUserDefaults standardUserDefaults] setURL:panel.URL
-                                                    forKey:@"HBLastDestinationDirectoryURL"];
+             [NSUserDefaults.standardUserDefaults setObject:[HBUtilities bookmarkFromURL:panel.URL]
+                                                       forKey:HBLastDestinationDirectoryBookmark];
+             [NSUserDefaults.standardUserDefaults setURL:panel.URL
+                                                  forKey:HBLastDestinationDirectoryURL];
 
          }
      }];
@@ -1003,38 +1040,6 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
     fRipIndicator.doubleValue = self.progress;
 }
 
-- (void)setQueueInfo:(NSString *)info progress:(double)progress hidden:(BOOL)hidden
-{
-    self.progressInfo = info;
-    self.progress = progress;
-
-    if (_visible)
-    {
-        [self updateProgress];
-    }
-
-    if (hidden)
-    {
-        if (fRipIndicatorShown)
-        {
-            self.bottomConstrain.animator.constant = -WINDOW_HEIGHT_OFFSET;
-            fRipIndicator.hidden = YES;
-            fRipIndicatorShown = NO;
-        }
-    }
-    else
-    {
-        // If progress bar hasn't been revealed at the bottom of the window, do
-        // that now.
-        if (!fRipIndicatorShown)
-        {
-            self.bottomConstrain.animator.constant = 0;
-            fRipIndicatorShown = YES;
-            fRipIndicator.hidden = NO;
-        }
-    }
-}
-
 #pragma mark - Job Handling
 
 /**
@@ -1050,13 +1055,16 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
         NSAlert *alert = [[NSAlert alloc] init];
         [alert setMessageText:NSLocalizedString(@"Warning!", @"Invalid destination alert -> message")];
         [alert setInformativeText:NSLocalizedString(@"This is not a valid destination directory!", @"Invalid destination alert -> informative text")];
+        [alert setAlertStyle:NSAlertStyleCritical];
         [alert beginSheetModalForWindow:self.window completionHandler:handler];
     }
-    else if ([job.fileURL isEqual:job.completeOutputURL])
+    else if ([job.fileURL isEqual:job.completeOutputURL]||
+             [job.fileURL.absoluteString.lowercaseString isEqualToString:job.completeOutputURL.absoluteString.lowercaseString])
     {
         NSAlert *alert = [[NSAlert alloc] init];
         [alert setMessageText:NSLocalizedString(@"A file already exists at the selected destination.", @"Destination same as source alert -> message")];
         [alert setInformativeText:NSLocalizedString(@"The destination is the same as the source, you can not overwrite your source file!", @"Destination same as source alert -> informative text")];
+        [alert setAlertStyle:NSAlertStyleCritical];
         [alert beginSheetModalForWindow:self.window completionHandler:handler];
     }
     else if ([[NSFileManager defaultManager] fileExistsAtPath:job.completeOutputURL.path])
@@ -1070,7 +1078,7 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
 
         [alert beginSheetModalForWindow:self.window completionHandler:handler];
     }
-    else if ([_queue jobExistAtURL:job.completeOutputURL])
+    else if ([_queue itemExistAtURL:job.completeOutputURL])
     {
         NSAlert *alert = [[NSAlert alloc] init];
         [alert setMessageText:NSLocalizedString(@"There is already a queue item for this destination.", @"File already exists in queue alert -> message")];
@@ -1120,24 +1128,19 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
         [self doAddToQueue];
     }
 
-    [_queue rip:self];
+    [_delegate toggleStartCancel:self];
 }
 
 /**
  * Puts up an alert before ultimately calling doRip
  */
-- (IBAction)rip:(id)sender
+- (IBAction)toggleStartCancel:(id)sender
 {
     // Rip or Cancel ?
-    if (_queue.core.state == HBStateWorking || _queue.core.state == HBStatePaused || _queue.core.state == HBStateSearching)
+    if (_queue.isEncoding || _queue.canEncode)
 	{
         // Displays an alert asking user if the want to cancel encoding of current job.
-        [_queue cancelRip:self];
-    }
-    // If there are pending jobs in the queue, then this is a rip the queue
-    else if (_queue.pendingItemsCount > 0)
-    {
-        [_queue rip:self];
+        [_delegate toggleStartCancel:self];
     }
     else
     {
@@ -1153,9 +1156,9 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
     }
 }
 
-- (IBAction)pause:(id)sender
+- (IBAction)togglePauseResume:(id)sender
 {
-    [_queue togglePauseResume:sender];
+    [_delegate togglePauseResume:sender];
 }
 
 #pragma mark -
@@ -1179,7 +1182,7 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
     [self doAddTitlesToQueue:titles];
 }
 
-- (void)doAddTitlesToQueue:(NSArray<HBTitle *> *)titles;
+- (void)doAddTitlesToQueue:(NSArray<HBTitle *> *)titles
 {
     NSMutableArray<HBJob *> *jobs = [[NSMutableArray alloc] init];
     BOOL fileExists = NO;
@@ -1192,7 +1195,7 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
     {
         HBJob *job = [[HBJob alloc] initWithTitle:title andPreset:preset];
         job.outputURL = self.currentDestination;
-        job.outputFileName = [HBUtilities defaultNameForJob:job];
+        job.outputFileName = job.defaultName;
         job.title = nil;
         [jobs addObject:job];
     }
@@ -1210,7 +1213,7 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
             [destinations addObject:job.completeOutputURL];
         }
 
-        if ([[NSFileManager defaultManager] fileExistsAtPath:job.completeOutputURL.path] || [_queue jobExistAtURL:job.completeOutputURL])
+        if ([[NSFileManager defaultManager] fileExistsAtPath:job.completeOutputURL.path] || [_queue itemExistAtURL:job.completeOutputURL])
         {
             fileExists = YES;
             break;
@@ -1245,13 +1248,13 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
         [alert beginSheetModalForWindow:self.window completionHandler:^(NSModalResponse returnCode) {
             if (returnCode == NSAlertSecondButtonReturn)
             {
-                [self->_queue addJobsFromArray:jobs];
+                [self->_queue addJobs:jobs];
             }
         }];
     }
     else
     {
-        [_queue addJobsFromArray:jobs];
+        [_queue addJobs:jobs];
     }
 }
 
@@ -1332,7 +1335,7 @@ static void *HBControllerQueueCoreContext = &HBControllerQueueCoreContext;
     }
 }
 
-- (void)reloadPreset:(id)sender;
+- (void)reloadPreset:(id)sender
 {
     // Reload the currently selected preset if it is selected.
     if (self.currentPreset != NULL)
@@ -1492,7 +1495,7 @@ static NSTouchBarItemIdentifier HBTouchBarActivity = @"fr.handbrake.activity";
     bar.defaultItemIdentifiers = @[HBTouchBarOpen, NSTouchBarItemIdentifierFixedSpaceSmall, HBTouchBarAddToQueue, NSTouchBarItemIdentifierFixedSpaceLarge, HBTouchBarRip, HBTouchBarPause, NSTouchBarItemIdentifierFixedSpaceLarge, HBTouchBarPreview, HBTouchBarActivity, NSTouchBarItemIdentifierOtherItemsProxy];
 
     bar.customizationIdentifier = HBTouchBarMain;
-    bar.customizationAllowedItemIdentifiers = @[HBTouchBarOpen, HBTouchBarAddToQueue, HBTouchBarAddTitlesToQueue, HBTouchBarRip, HBTouchBarPause, HBTouchBarPreview, HBTouchBarActivity, NSTouchBarItemIdentifierFixedSpaceSmall, NSTouchBarItemIdentifierFixedSpaceLarge, NSTouchBarItemIdentifierFlexibleSpace];
+    bar.customizationAllowedItemIdentifiers = @[HBTouchBarOpen, HBTouchBarAddToQueue, HBTouchBarAddTitlesToQueue, HBTouchBarRip, HBTouchBarPause, HBTouchBarPreview, HBTouchBarActivity, NSTouchBarItemIdentifierFlexibleSpace];
 
     return bar;
 }
@@ -1534,7 +1537,7 @@ static NSTouchBarItemIdentifier HBTouchBarActivity = @"fr.handbrake.activity";
         NSCustomTouchBarItem *item = [[NSCustomTouchBarItem alloc] initWithIdentifier:identifier];
         item.customizationLabel = NSLocalizedString(@"Start/Stop Encoding", @"Touch bar");
 
-        NSButton *button = [NSButton buttonWithImage:[NSImage imageNamed:NSImageNameTouchBarPlayTemplate] target:self action:@selector(rip:)];
+        NSButton *button = [NSButton buttonWithImage:[NSImage imageNamed:NSImageNameTouchBarPlayTemplate] target:self action:@selector(toggleStartCancel:)];
 
         item.view = button;
         return item;
@@ -1544,7 +1547,7 @@ static NSTouchBarItemIdentifier HBTouchBarActivity = @"fr.handbrake.activity";
         NSCustomTouchBarItem *item = [[NSCustomTouchBarItem alloc] initWithIdentifier:identifier];
         item.customizationLabel = NSLocalizedString(@"Pause Encoding", @"Touch bar");
 
-        NSButton *button = [NSButton buttonWithImage:[NSImage imageNamed:NSImageNameTouchBarPauseTemplate] target:self action:@selector(pause:)];
+        NSButton *button = [NSButton buttonWithImage:[NSImage imageNamed:NSImageNameTouchBarPauseTemplate] target:self action:@selector(togglePauseResume:)];
 
         item.view = button;
         return item;
@@ -1589,24 +1592,26 @@ static NSTouchBarItemIdentifier HBTouchBarActivity = @"fr.handbrake.activity";
     }
 }
 
-- (void)_touchBar_updateButtonsStateForQueueCore:(HBState)state;
+- (void)_touchBar_updateQueueButtonsState
 {
     NSButton *ripButton = (NSButton *)[[self.touchBar itemForIdentifier:HBTouchBarRip] view];
     NSButton *pauseButton = (NSButton *)[[self.touchBar itemForIdentifier:HBTouchBarPause] view];
 
-    if (state == HBStateScanning || state == HBStateWorking || state == HBStateSearching || state == HBStateMuxing)
+    if (self.queue.isEncoding)
     {
         ripButton.image = [NSImage imageNamed:NSImageNameTouchBarRecordStopTemplate];
-        pauseButton.image = [NSImage imageNamed:NSImageNameTouchBarPauseTemplate];
     }
-    else if (state == HBStatePaused)
-    {
-        ripButton.image = [NSImage imageNamed:NSImageNameTouchBarRecordStopTemplate];
-        pauseButton.image = [NSImage imageNamed:NSImageNameTouchBarPlayTemplate];
-    }
-    else if (state == HBStateIdle)
+    else
     {
         ripButton.image = [NSImage imageNamed:NSImageNameTouchBarPlayTemplate];
+    }
+
+    if (self.queue.canResume)
+    {
+        pauseButton.image = [NSImage imageNamed:NSImageNameTouchBarPlayTemplate];
+    }
+    else
+    {
         pauseButton.image = [NSImage imageNamed:NSImageNameTouchBarPauseTemplate];
     }
 }
