@@ -96,7 +96,7 @@ typedef void (^HBCoreCleanupHandler)(void);
     return [self initWithLogLevel:0 queue:dispatch_get_main_queue()];
 }
 
-- (instancetype)initWithLogLevel:(int)level queue:(dispatch_queue_t)queue
+- (instancetype)initWithLogLevel:(NSInteger)level queue:(dispatch_queue_t)queue
 {
     self = [super init];
     if (self)
@@ -112,7 +112,7 @@ typedef void (^HBCoreCleanupHandler)(void);
         bzero(_hb_state, sizeof(hb_state_t));
         _logLevel = level;
 
-        _hb_handle = hb_init(level);
+        _hb_handle = hb_init((int)level);
         if (!_hb_handle)
         {
             return nil;
@@ -122,7 +122,7 @@ typedef void (^HBCoreCleanupHandler)(void);
     return self;
 }
 
-- (instancetype)initWithLogLevel:(int)level name:(NSString *)name
+- (instancetype)initWithLogLevel:(NSInteger)level name:(NSString *)name
 {
     self = [self initWithLogLevel:level queue:dispatch_get_main_queue()];
     if (self)
@@ -144,10 +144,10 @@ typedef void (^HBCoreCleanupHandler)(void);
     free(_hb_state);
 }
 
-- (void)setLogLevel:(int)logLevel
+- (void)setLogLevel:(NSInteger)logLevel
 {
     _logLevel = logLevel;
-    hb_log_level_set(_hb_handle, logLevel);
+    hb_log_level_set(_hb_handle, (int)logLevel);
 }
 
 - (void)preventSleep
@@ -187,7 +187,7 @@ typedef void (^HBCoreCleanupHandler)(void);
     NSAssert(url, @"[HBCore canScan:] called with nil url.");
 
 #ifdef __SANDBOX_ENABLED__
-    BOOL accessingSecurityScopedResource = [url startAccessingSecurityScopedResource];
+    __unused HBSecurityAccessToken *token = [HBSecurityAccessToken tokenWithObject:url];
 #endif
 
     if (![[NSFileManager defaultManager] fileExistsAtPath:url.path]) {
@@ -210,10 +210,18 @@ typedef void (^HBCoreCleanupHandler)(void);
         if (detector.isVideoDVD)
         {
             lib = dlopen("libdvdcss.2.dylib", RTLD_LAZY);
+            if (!lib)
+            {
+                lib = dlopen("/usr/local/lib/libdvdcss.2.dylib", RTLD_LAZY);
+            }
         }
         else if (detector.isVideoBluRay)
         {
             lib = dlopen("libaacs.dylib", RTLD_LAZY);
+            if (!lib)
+            {
+                lib = dlopen("/usr/local/lib/libaacs.dylib", RTLD_LAZY);
+            }
         }
 
         if (lib)
@@ -223,6 +231,13 @@ typedef void (^HBCoreCleanupHandler)(void);
         }
         else
         {
+            const char *dlError = dlerror();
+
+            if (dlError)
+            {
+                [HBUtilities writeToActivityLog:"dlopen error: %s", dlError];
+            }
+
             // Notify the user that we don't support removal of copy protection.
             [HBUtilities writeToActivityLog:"%s, library not found for decrypting physical disc", self.name.UTF8String];
 
@@ -235,16 +250,13 @@ typedef void (^HBCoreCleanupHandler)(void);
     }
 
 #ifdef __SANDBOX_ENABLED__
-    if (accessingSecurityScopedResource)
-    {
-        [url stopAccessingSecurityScopedResource];
-    }
+    token = nil;
 #endif
 
     return YES;
 }
 
-- (void)scanURL:(NSURL *)url titleIndex:(NSUInteger)index previews:(NSUInteger)previewsNum minDuration:(NSUInteger)seconds progressHandler:(HBCoreProgressHandler)progressHandler completionHandler:(HBCoreCompletionHandler)completionHandler
+- (void)scanURL:(NSURL *)url titleIndex:(NSUInteger)index previews:(NSUInteger)previewsNum minDuration:(NSUInteger)seconds keepPreviews:(BOOL)keepPreviews progressHandler:(HBCoreProgressHandler)progressHandler completionHandler:(HBCoreCompletionHandler)completionHandler
 {
     NSAssert(self.state == HBStateIdle, @"[HBCore scanURL:] called while another scan or encode already in progress");
     NSAssert(url, @"[HBCore scanURL:] called with nil url.");
@@ -281,7 +293,7 @@ typedef void (^HBCoreCleanupHandler)(void);
 
     hb_scan(_hb_handle, url.fileSystemRepresentation,
             (int)index, (int)previewsNum,
-            1, min_title_duration_ticks);
+            keepPreviews, min_title_duration_ticks);
 
     // Start the timer to handle libhb state changes
     [self startUpdateTimerWithInterval:0.2];
@@ -320,7 +332,7 @@ typedef void (^HBCoreCleanupHandler)(void);
 }
 
 #pragma mark - Preview images
-        
+
 - (CGImageRef)copyImageAtIndex:(NSUInteger)index
                       forTitle:(HBTitle *)title
                   pictureFrame:(HBPicture *)frame
@@ -391,7 +403,7 @@ typedef void (^HBCoreCleanupHandler)(void);
         hb_image_close(&image);
     }
 
-    if (angle || flipped)
+    if (img && (angle || flipped))
     {
         CGImageRef rotatedImg = CGImageRotated(img, angle, flipped);
         CGImageRelease(img);
@@ -410,7 +422,7 @@ typedef void (^HBCoreCleanupHandler)(void);
 
 #pragma mark - Encodes
 
-- (void)encodeJob:(HBJob *)job progressHandler:(HBCoreProgressHandler)progressHandler completionHandler:(HBCoreCompletionHandler)completionHandler;
+- (void)encodeJob:(HBJob *)job progressHandler:(HBCoreProgressHandler)progressHandler completionHandler:(HBCoreCompletionHandler)completionHandler
 {
     NSAssert(self.state == HBStateIdle, @"[HBCore encodeJob:] called while another scan or encode already in progress");
     NSAssert(job, @"[HBCore encodeJob:] called with nil job");
@@ -453,7 +465,7 @@ typedef void (^HBCoreCleanupHandler)(void);
 {
     [self stopProgressReporting];
 
-    // HB_STATE_WORKDONE happpens as a result of libhb finishing all its jobs
+    // HB_STATE_WORKDONE happens as a result of libhb finishing all its jobs
     // or someone calling hb_stop. In the latter case, hb_stop does not clear
     // out the remaining passes/jobs in the queue. We'll do that here.
     hb_job_t *job;
@@ -505,15 +517,18 @@ typedef void (^HBCoreCleanupHandler)(void);
 
 - (void)startProgressReporting:(NSURL *)fileURL
 {
-    NSDictionary *userInfo = @{NSProgressFileURLKey : fileURL};
+    if (fileURL)
+    {
+        NSDictionary *userInfo = @{NSProgressFileURLKey : fileURL};
 
-    self.progress = [[NSProgress alloc] initWithParent:nil userInfo:userInfo];
-    self.progress.totalUnitCount = 100;
-    self.progress.kind = NSProgressKindFile;
-    self.progress.pausable = NO;
-    self.progress.cancellable = NO;
+        self.progress = [[NSProgress alloc] initWithParent:nil userInfo:userInfo];
+        self.progress.totalUnitCount = 100;
+        self.progress.kind = NSProgressKindFile;
+        self.progress.pausable = NO;
+        self.progress.cancellable = NO;
 
-    [self.progress publish];
+        [self.progress publish];
+    }
 }
 
 - (void)stopProgressReporting
@@ -615,7 +630,8 @@ typedef void (^HBCoreCleanupHandler)(void);
 
         self.progressHandler(self.state, progress, info);
 
-        if (self.progress.completedUnitCount < progress.percent * 100)
+        if (state.state != HB_STATE_SEARCHING &&
+            self.progress.completedUnitCount < progress.percent * 100)
         {
             self.progress.completedUnitCount = progress.percent * 100;
         }
