@@ -43,7 +43,7 @@
 @property (nonatomic) HBPictureController *pictureSettingsWindow;
 
 @property (nonatomic) NSPoint windowCenterPoint;
-@property (weak) IBOutlet HBPreviewView *previewView;
+@property (nonatomic, weak) IBOutlet HBPreviewView *previewView;
 
 @end
 
@@ -63,12 +63,12 @@
     // We need the center and we can't use the
     // standard NSWindow autosave because we change
     // the window size at startup.
-    NSString *centerString = [[NSUserDefaults standardUserDefaults] objectForKey:@"HBPreviewWindowCenter"];
+    NSString *centerString = [NSUserDefaults.standardUserDefaults stringForKey:@"HBPreviewWindowCenter"];
     if (centerString.length)
     {
         NSPoint center = NSPointFromString(centerString);
         self.windowCenterPoint = center;
-        [self.window HB_resizeToBestSizeForViewSize:NSMakeSize(MIN_WIDTH, MIN_HEIGHT) center:self.windowCenterPoint animate:NO];
+        [self.window HB_resizeToBestSizeForViewSize:NSMakeSize(MIN_WIDTH, MIN_HEIGHT) keepInScreenRect:YES centerPoint:center animate:NO];
     }
     else
     {
@@ -167,7 +167,13 @@
         self.window.title = NSLocalizedString(@"Preview", @"Preview -> window title");
         self.pictureHUD.generator = nil;
     }
+
     [self switchStateToHUD:self.pictureHUD];
+
+    if (generator)
+    {
+        [self resizeToOptimalSize];
+    }
 }
 
 - (void)reloadPreviews
@@ -176,6 +182,7 @@
     {
         [self.generator cancel];
         [self switchStateToHUD:self.pictureHUD];
+        [self resizeToOptimalSize];
     }
 }
 
@@ -204,20 +211,43 @@
     [self.generator purgeImageCache];
 }
 
+#pragma mark - Window sizing
+
+- (void)resizeToOptimalSize
+{
+    if (!(self.window.styleMask & NSWindowStyleMaskFullScreen))
+    {
+        if (self.previewView.fitToView)
+        {
+            [self.window setFrame:self.window.screen.visibleFrame display:YES animate:YES];
+        }
+        else
+        {
+            // Get the optimal view size for the image
+            NSSize windowSize = [self.previewView optimalViewSizeForImageSize:self.generator.imageSize
+                                                                      minSize:NSMakeSize(MIN_WIDTH, MIN_HEIGHT)
+                                                                  scaleFactor:self.window.backingScaleFactor];
+            // Scale the window to the image size
+            [self.window HB_resizeToBestSizeForViewSize:windowSize keepInScreenRect:YES centerPoint:NSZeroPoint animate:self.window.isVisible];
+        }
+    }
+
+    [self updateSizeLabels];
+}
+
 - (void)windowDidChangeBackingProperties:(NSNotification *)notification
 {
     NSWindow *theWindow = (NSWindow *)notification.object;
 
     CGFloat newBackingScaleFactor = theWindow.backingScaleFactor;
-    CGFloat oldBackingScaleFactor = [notification.userInfo[@"NSBackingPropertyOldScaleFactorKey"] doubleValue];
+    CGFloat oldBackingScaleFactor = [notification.userInfo[NSBackingPropertyOldScaleFactorKey] doubleValue];
 
     if (newBackingScaleFactor != oldBackingScaleFactor)
     {
-        // Scale factor changed, update the preview window
-        // to the new situation
+        // Scale factor changed, resize the preview window
         if (self.generator)
         {
-            [self reloadPreviews];
+            [self resizeToOptimalSize];
         }
     }
 }
@@ -229,13 +259,20 @@
     if (self.previewView.fitToView == NO)
     {
         self.windowCenterPoint = [self.window HB_centerPoint];
-        [[NSUserDefaults standardUserDefaults] setObject:NSStringFromPoint(self.windowCenterPoint) forKey:@"HBPreviewWindowCenter"];
+        [NSUserDefaults.standardUserDefaults setObject:NSStringFromPoint(self.windowCenterPoint) forKey:@"HBPreviewWindowCenter"];
     }
 }
 
 - (void)windowDidResize:(NSNotification *)notification
 {
     [self updateSizeLabels];
+    if (self.currentHUD == self.playerHUD)
+    {
+        [CATransaction begin];
+        CATransaction.disableActions = YES;
+        self.player.layer.frame = self.previewView.pictureFrame;
+        [CATransaction commit];
+    }
 }
 
 - (void)updateSizeLabels
@@ -247,7 +284,7 @@
         NSMutableString *scaleString = [NSMutableString string];
         if (scale * 100.0 != 100)
         {
-            [scaleString appendFormat:NSLocalizedString(@"(%.0f%% actual size)", @"Preview -> size info label"), scale * 100.0];
+            [scaleString appendFormat:NSLocalizedString(@"(%.0f%% actual size)", @"Preview -> size info label"), floor(scale * 100.0)];
         }
         else
         {
@@ -269,6 +306,12 @@
     }
 }
 
+- (void)toggleScaleToScreen
+{
+    self.previewView.fitToView = !self.previewView.fitToView;
+    [self resizeToOptimalSize];
+}
+
 #pragma mark - Hud State
 
 /**
@@ -299,14 +342,16 @@
     // Show the current hud
     NSMutableArray<NSViewController<HBHUD> *> *huds = [@[self.pictureHUD, self.encodingHUD, self.playerHUD] mutableCopy];
     [huds removeObject:hud];
-    for (NSViewController *controller in huds) {
+    for (NSViewController *controller in huds)
+    {
         controller.view.hidden = YES;
     }
+
     if (self.generator)
     {
         hud.view.hidden = NO;
         hud.view.layer.opacity = 1.0;
-    };
+    }
 
     [self.window makeFirstResponder:hud.view];
     [self startHudTimer];
@@ -431,51 +476,13 @@
     [self displayPreviewAtIndex:self.pictureHUD.selectedIndex];
 }
 
-/**
- * Adjusts the window to draw the current picture (fPicture) adjusting its size as
- * necessary to display as much of the picture as possible.
- */
 - (void)displayPreviewAtIndex:(NSUInteger)idx
 {
-    if (!self.generator)
+    if (self.generator && self.window.isVisible)
     {
-        return;
-    }
-
-    if (self.window.isVisible)
-    {
-        CGImageRef fPreviewImage = [self.generator copyImageAtIndex:idx shouldCache:YES];
-        [self.previewView setImage:fPreviewImage];
-        CFRelease(fPreviewImage);
-    }
-
-    if (self.previewView.fitToView == NO && !(self.window.styleMask & NSWindowStyleMaskFullScreen))
-    {
-        // Get the optimal view size for the image
-        NSSize imageScaledSize = [self.generator imageSize];
-
-        // Scale the window to the image size
-        NSSize windowSize = [self.previewView optimalViewSizeForImageSize:imageScaledSize minSize:NSMakeSize(MIN_WIDTH, MIN_HEIGHT)];
-        [self.window HB_resizeToBestSizeForViewSize:windowSize center:self.windowCenterPoint animate:self.window.isVisible];
-    }
-
-    [self updateSizeLabels];
-}
-
-- (void)toggleScaleToScreen
-{
-    if (self.previewView.fitToView == YES)
-    {
-        self.previewView.fitToView = NO;
-        [self displayPreviewAtIndex:self.pictureHUD.selectedIndex];
-    }
-    else
-    {
-        self.previewView.fitToView = YES;
-        if (!(self.window.styleMask & NSWindowStyleMaskFullScreen))
-        {
-            [self.window setFrame:self.window.screen.visibleFrame display:YES animate:YES];
-        }
+        CGImageRef image = [self.generator copyImageAtIndex:idx shouldCache:YES];
+        self.previewView.image = image;
+        CFRelease(image);
     }
 }
 
@@ -522,7 +529,7 @@
     [self switchStateToHUD:self.pictureHUD];
 }
 
-- (void)showAlert:(NSURL *)fileURL;
+- (void)showAlert:(NSURL *)fileURL
 {
     NSAlert *alert = [[NSAlert alloc] init];
     alert.messageText = NSLocalizedString(@"HandBrake can't open the preview.", @"Preview -> live preview alert message");
@@ -539,7 +546,7 @@
     }];
 }
 
-- (void)setUpPlaybackOfURL:(NSURL *)fileURL playerClass:(Class)class;
+- (void)setUpPlaybackOfURL:(NSURL *)fileURL playerClass:(Class)class
 {
     NSArray<Class> *availablePlayerClasses = @[[HBAVPlayer class]];
 
@@ -593,8 +600,7 @@
     CALayer *playerLayer = self.player.layer;
     playerLayer.frame = self.previewView.pictureFrame;
 
-    [self.window.contentView.layer insertSublayer:playerLayer atIndex:1];
-
+    [self.previewView.layer insertSublayer:playerLayer atIndex:10];
     self.playerHUD.player = self.player;
 }
 
@@ -615,7 +621,7 @@
 
 - (void)keyDown:(NSEvent *)event
 {
-    if ([self.currentHUD HB_keyDown:event] == NO)
+    if (self.generator && [self.currentHUD HB_keyDown:event] == NO)
     {
         [super keyDown:event];
     }
@@ -623,7 +629,7 @@
 
 - (void)scrollWheel:(NSEvent *)event
 {
-    if ([self.currentHUD HB_scrollWheel:event] == NO)
+    if (self.generator && [self.currentHUD HB_scrollWheel:event] == NO)
     {
         [super scrollWheel:event];
     }
