@@ -1,12 +1,13 @@
-//
-//  HBSecurityAccessToken.h
-//  HandBrake
-//
-//  Created by Damiano Galassi on 24/01/17.
-//
-//
+/*  HBSecurityAccessToken.h $
+
+ This file is part of the HandBrake source code.
+ Homepage: <http://handbrake.fr/>.
+ It may be used under the terms of the GNU General Public License. */
 
 #import <Foundation/Foundation.h>
+#import "HBJob.h"
+
+NS_ASSUME_NONNULL_BEGIN
 
 @protocol HBSecurityScope <NSObject>
 
@@ -21,10 +22,9 @@
 @end
 
 @interface NSURL (HBSecurityScope) <HBSecurityScope>
+@end
 
-- (BOOL)startAccessingSecurityScopedResource;
-- (void)stopAccessingSecurityScopedResource;
-
+@interface HBJob (HBSecurityScope) <HBSecurityScope>
 @end
 
 @interface HBSecurityAccessToken : NSObject
@@ -33,3 +33,5 @@
 - (instancetype)initWithObject:(id<HBSecurityScope>)object;
 
 @end
+
+NS_ASSUME_NONNULL_END
