@@ -6,9 +6,14 @@
 
 #import <Foundation/Foundation.h>
 
+NS_ASSUME_NONNULL_BEGIN
+
 @interface NSArray (HBAdditions)
 
 - (NSArray *)filteredArrayUsingBlock:(BOOL (^)(id object))block;
 - (NSIndexSet *)indexesOfObjectsUsingBlock:(BOOL (^)(id object))block;
 
-@end
\ No newline at end of file
+@end
+
+NS_ASSUME_NONNULL_END
+
