@@ -1,5 +1,5 @@
 ﻿// --------------------------------------------------------------------------------------------------------------------
-// <copyright file="HandBrakeInstance.cs" company="HandBrake Project (http://handbrake.fr)">
+// <copyright file="HandBrakeInstance.cs" company="HandBrake Project (https://handbrake.fr)">
 //   This file is part of the HandBrake source code - It may be used under the terms of the GNU General Public License.
 // </copyright>
 // <summary>
@@ -20,6 +20,7 @@ namespace HandBrake.Interop.Interop
     using HandBrake.Interop.Interop.EventArgs;
     using HandBrake.Interop.Interop.Factories;
     using HandBrake.Interop.Interop.HbLib;
+    using HandBrake.Interop.Interop.HbLib.Wrappers.Interfaces;
     using HandBrake.Interop.Interop.Helpers;
     using HandBrake.Interop.Interop.Interfaces;
     using HandBrake.Interop.Interop.Json.Encode;
@@ -27,11 +28,14 @@ namespace HandBrake.Interop.Interop
     using HandBrake.Interop.Interop.Json.State;
     using HandBrake.Interop.Interop.Model.Encoding;
     using HandBrake.Interop.Interop.Model.Preview;
+    using HandBrake.Interop.Interop.Providers;
+    using HandBrake.Interop.Interop.Providers.Interfaces;
 
     using Newtonsoft.Json;
 
     public class HandBrakeInstance : IHandBrakeInstance, IDisposable
     {
+        private IHbFunctions hbFunctions;
         private const double ScanPollIntervalMs = 250;
         private const double EncodePollIntervalMs = 250;
         private Timer scanPollTimer;
@@ -97,12 +101,12 @@ namespace HandBrake.Interop.Interop
         /// <summary>
         /// Gets the HandBrake version string.
         /// </summary>
-        public string Version => Marshal.PtrToStringAnsi(HBFunctions.hb_get_version(this.Handle));
+        public string Version => Marshal.PtrToStringAnsi(hbFunctions.hb_get_version(this.Handle));
 
         /// <summary>
         /// Gets the HandBrake build number.
         /// </summary>
-        public int Build => HBFunctions.hb_get_build(this.Handle);
+        public int Build => hbFunctions.hb_get_build(this.Handle);
 
         /// <summary>
         /// Initializes this instance.
@@ -110,12 +114,18 @@ namespace HandBrake.Interop.Interop
         /// <param name="verbosity">
         /// The code for the logging verbosity to use.
         /// </param>
-        public void Initialize(int verbosity)
+        /// <param name="noHardware">
+        /// True disables hardware init.
+        /// </param>
+        public void Initialize(int verbosity, bool noHardware)
         {
-            HandBrakeUtils.EnsureGlobalInit();
+            IHbFunctionsProvider hbFunctionsProvider = new HbFunctionsProvider();
+            hbFunctions = hbFunctionsProvider.GetHbFunctionsWrapper();
+
+            HandBrakeUtils.EnsureGlobalInit(noHardware);
 
             HandBrakeUtils.RegisterLogger();
-            this.Handle = HBFunctions.hb_init(verbosity, update_check: 0);
+            this.Handle = hbFunctions.hb_init(verbosity, update_check: 0);
         }
 
         /// <summary>
@@ -138,7 +148,7 @@ namespace HandBrake.Interop.Interop
             this.PreviewCount = previewCount;
 
             IntPtr pathPtr = InteropUtilities.ToUtf8PtrFromString(path);
-            HBFunctions.hb_scan(this.Handle, pathPtr, titleIndex, previewCount, 1, (ulong)(minDuration.TotalSeconds * 90000));
+            hbFunctions.hb_scan(this.Handle, pathPtr, titleIndex, previewCount, 1, (ulong)(minDuration.TotalSeconds * 90000));
             Marshal.FreeHGlobal(pathPtr);
 
             this.scanPollTimer = new Timer();
@@ -166,7 +176,8 @@ namespace HandBrake.Interop.Interop
         [HandleProcessCorruptedStateExceptions]
         public void StopScan()
         {
-            HBFunctions.hb_scan_stop(this.Handle);
+            this.scanPollTimer.Stop();
+            hbFunctions.hb_scan_stop(this.Handle);
         }
 
         /// <summary>
@@ -213,7 +224,7 @@ namespace HandBrake.Interop.Interop
             };
 
             // Fetch the image data from LibHb
-            IntPtr resultingImageStuct = HBFunctions.hb_get_preview2(this.Handle, settings.TitleNumber, previewNumber, ref uiGeometry, deinterlace ? 1 : 0);
+            IntPtr resultingImageStuct = hbFunctions.hb_get_preview2(this.Handle, settings.TitleNumber, previewNumber, ref uiGeometry, deinterlace ? 1 : 0);
             hb_image_s image = InteropUtilities.ToStructureFromPtr<hb_image_s>(resultingImageStuct);
 
             // Copy the filled image buffer to a managed array.
@@ -229,7 +240,7 @@ namespace HandBrake.Interop.Interop
             // Close the image so we don't leak memory.
             IntPtr nativeJobPtrPtr = Marshal.AllocHGlobal(Marshal.SizeOf(typeof(IntPtr)));
             Marshal.WriteIntPtr(nativeJobPtrPtr, resultingImageStuct);
-            HBFunctions.hb_image_close(nativeJobPtrPtr);
+            hbFunctions.hb_image_close(nativeJobPtrPtr);
             Marshal.FreeHGlobal(nativeJobPtrPtr);
 
             return preview;
@@ -244,7 +255,7 @@ namespace HandBrake.Interop.Interop
         /// <returns>True if DRC can be applied to the track with the given encoder.</returns>
         public bool CanApplyDrc(int trackNumber, HBAudioEncoder encoder, int title)
         {
-            return HBFunctions.hb_audio_can_apply_drc2(this.Handle, title, trackNumber, encoder.Id) > 0;
+            return hbFunctions.hb_audio_can_apply_drc2(this.Handle, title, trackNumber, encoder.Id) > 0;
         }
 
         /// <summary>
@@ -272,8 +283,8 @@ namespace HandBrake.Interop.Interop
         [HandleProcessCorruptedStateExceptions]
         public void StartEncode(string encodeJson)
         {
-            HBFunctions.hb_add_json(this.Handle, InteropUtilities.ToUtf8PtrFromString(encodeJson));
-            HBFunctions.hb_start(this.Handle);
+            hbFunctions.hb_add_json(this.Handle, InteropUtilities.ToUtf8PtrFromString(encodeJson));
+            hbFunctions.hb_start(this.Handle);
 
             this.encodePollTimer = new Timer();
             this.encodePollTimer.Interval = EncodePollIntervalMs;
@@ -298,7 +309,7 @@ namespace HandBrake.Interop.Interop
         [HandleProcessCorruptedStateExceptions]
         public void PauseEncode()
         {
-            HBFunctions.hb_pause(this.Handle);
+            hbFunctions.hb_pause(this.Handle);
         }
 
         /// <summary>
@@ -307,7 +318,7 @@ namespace HandBrake.Interop.Interop
         [HandleProcessCorruptedStateExceptions]
         public void ResumeEncode()
         {
-            HBFunctions.hb_resume(this.Handle);
+            hbFunctions.hb_resume(this.Handle);
         }
 
         /// <summary>
@@ -316,20 +327,20 @@ namespace HandBrake.Interop.Interop
         [HandleProcessCorruptedStateExceptions]
         public void StopEncode()
         {
-            HBFunctions.hb_stop(this.Handle);
+            hbFunctions.hb_stop(this.Handle);
 
             // Also remove all jobs from the queue (in case we stopped a 2-pass encode)
             var currentJobs = new List<IntPtr>();
 
-            int jobs = HBFunctions.hb_count(this.Handle);
+            int jobs = hbFunctions.hb_count(this.Handle);
             for (int i = 0; i < jobs; i++)
             {
-                currentJobs.Add(HBFunctions.hb_job(this.Handle, 0));
+                currentJobs.Add(hbFunctions.hb_job(this.Handle, 0));
             }
 
             foreach (IntPtr job in currentJobs)
             {
-                HBFunctions.hb_rem(this.Handle, job);
+                hbFunctions.hb_rem(this.Handle, job);
             }
         }
 
@@ -342,7 +353,7 @@ namespace HandBrake.Interop.Interop
         [HandleProcessCorruptedStateExceptions]
         public JsonState GetEncodeProgress()
         {
-            IntPtr json = HBFunctions.hb_get_state_json(this.Handle);
+            IntPtr json = hbFunctions.hb_get_state_json(this.Handle);
             string statusJson = Marshal.PtrToStringAnsi(json);
 
             JsonState state = JsonConvert.DeserializeObject<JsonState>(statusJson);
@@ -390,7 +401,7 @@ namespace HandBrake.Interop.Interop
             // Free unmanaged objects.
             IntPtr handlePtr = Marshal.AllocHGlobal(Marshal.SizeOf(typeof(IntPtr)));
             Marshal.WriteIntPtr(handlePtr, this.Handle);
-            HBFunctions.hb_close(handlePtr);
+            hbFunctions.hb_close(handlePtr);
             Marshal.FreeHGlobal(handlePtr);
 
             this.disposed = true;
@@ -402,7 +413,7 @@ namespace HandBrake.Interop.Interop
         [HandleProcessCorruptedStateExceptions]
         private void PollScanProgress()
         {
-            IntPtr json = HBFunctions.hb_get_state_json(this.Handle);
+            IntPtr json = hbFunctions.hb_get_state_json(this.Handle);
             string statusJson = Marshal.PtrToStringAnsi(json);
             JsonState state = null;
             if (!string.IsNullOrEmpty(statusJson))
@@ -423,7 +434,7 @@ namespace HandBrake.Interop.Interop
             {
                 this.scanPollTimer.Stop();
 
-                var jsonMsg = HBFunctions.hb_get_title_set_json(this.Handle);
+                var jsonMsg = hbFunctions.hb_get_title_set_json(this.Handle);
                 this.TitlesJson = InteropUtilities.ToStringFromUtf8Ptr(jsonMsg);
 
                 if (!string.IsNullOrEmpty(this.TitlesJson))
@@ -448,7 +459,7 @@ namespace HandBrake.Interop.Interop
         [HandleProcessCorruptedStateExceptions]
         private void PollEncodeProgress()
         {
-            IntPtr json = HBFunctions.hb_get_state_json(this.Handle);
+            IntPtr json = hbFunctions.hb_get_state_json(this.Handle);
             string statusJson = Marshal.PtrToStringAnsi(json);
 
             JsonState state = JsonConvert.DeserializeObject<JsonState>(statusJson);
@@ -459,8 +470,8 @@ namespace HandBrake.Interop.Interop
             {
                 if (this.EncodeProgress != null)
                 {
-                    var progressEventArgs = new EncodeProgressEventArgs(state.Working.Progress, state.Working.Rate, state.Working.RateAvg, new TimeSpan(state.Working.Hours, state.Working.Minutes, state.Working.Seconds),
-                        state.Working.PassID, state.Working.Pass, state.Working.PassCount, taskState.Code);
+                    TimeSpan eta = TimeSpan.FromSeconds(state.Working.ETASeconds);
+                    var progressEventArgs = new EncodeProgressEventArgs(state.Working.Progress, state.Working.Rate, state.Working.RateAvg, eta, state.Working.PassID, state.Working.Pass, state.Working.PassCount, taskState.Code);
 
                     this.EncodeProgress(this, progressEventArgs);
                 }
