@@ -27,9 +27,7 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
 
     using Newtonsoft.Json;
 
-    /// <summary>
-    /// Model of a HandBrake Audio Track and it's associated behaviours.
-    /// </summary>
+    [JsonObject(MemberSerialization.OptOut)]
     public class AudioTrack : PropertyChangedBase
     {
         private int bitrate;
@@ -46,6 +44,7 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
         private IEnumerable<double> encoderQualityValues;
         private AudioEncoderRateType encoderRateType;
         private double? quality;
+        private string trackName;
 
         /// <summary>
         ///   Initializes a new instance of the <see cref = "AudioTrack" /> class.
@@ -61,6 +60,11 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             this.ScannedTrack = new Audio();
             this.TrackName = string.Empty;
 
+            if (!string.IsNullOrEmpty(this.scannedTrack?.Name))
+            {
+                this.TrackName = this.scannedTrack.Name;
+            }
+
             // Setup Backing Properties
             this.EncoderRateType = HandBrakeWPF.Services.Encode.Model.Models.AudioEncoderRateType.Bitrate;
             this.SetupLimits();
@@ -88,7 +92,17 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             {
                 this.scannedTrack = track.ScannedTrack ?? new Audio();
             }
-            this.TrackName = track.TrackName;
+
+            if (!string.IsNullOrEmpty(this.scannedTrack?.Name))
+            {
+                this.TrackName = this.scannedTrack.Name;
+            }
+
+            if (!string.IsNullOrEmpty(track.TrackName))
+            {
+                this.TrackName = track.TrackName;
+            }
+
             this.Quality = track.Quality;
 
             // Setup Backing Properties
@@ -139,6 +153,11 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             this.encoderRateType = track.EncoderRateType;
             this.quality = track.Quality;
             this.bitrate = track.Bitrate;
+            
+            if (!string.IsNullOrEmpty(this.scannedTrack?.Name))
+            {
+                this.TrackName = this.scannedTrack.Name;
+            }
 
             this.SetupLimits();
         }
@@ -323,7 +342,17 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
         /// <summary>
         /// Gets or sets the track name.
         /// </summary>
-        public string TrackName { get; set; }
+        public string TrackName
+        {
+            get => this.trackName;
+            set
+            {
+                if (value == this.trackName) return;
+                this.trackName = value;
+                this.NotifyOfPropertyChange();
+            }
+        }
+
         #endregion
 
         /// <summary>
@@ -415,6 +444,8 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
                 this.NotifyOfPropertyChange(() => this.ScannedTrack);
                 this.NotifyOfPropertyChange(() => this.TrackReference);
 
+                this.TrackName = !string.IsNullOrEmpty(this.scannedTrack?.Name) ? this.scannedTrack.Name : null;
+
                 this.GetDefaultMixdownIfNull();
             }
         }
