@@ -21,22 +21,26 @@ namespace HandBrakeWPF.Services
 
     using HandBrakeWPF.EventArgs;
     using HandBrakeWPF.Instance;
+    using HandBrakeWPF.Model.Options;
     using HandBrakeWPF.Properties;
     using HandBrakeWPF.Services.Interfaces;
+    using HandBrakeWPF.Services.Logging;
+    using HandBrakeWPF.Services.Logging.Model;
     using HandBrakeWPF.Services.Queue.Interfaces;
     using HandBrakeWPF.Services.Scan.Interfaces;
     using HandBrakeWPF.Utilities;
     using HandBrakeWPF.ViewModels.Interfaces;
 
     using EncodeCompletedEventArgs = HandBrakeWPF.Services.Encode.EventArgs.EncodeCompletedEventArgs;
-    using Execute = Caliburn.Micro.Execute;
+    using ILog = HandBrakeWPF.Services.Logging.Interfaces.ILog;
 
     /// <summary>
     /// The when done service.
     /// </summary>
     public class PrePostActionService : IPrePostActionService
     {
-        private readonly IQueueProcessor queueProcessor;
+        private readonly ILog log = LogService.GetLogger();
+        private readonly IQueueService queueProcessor;
         private readonly IUserSettingService userSettingService;
         private readonly IWindowManager windowManager;
         private readonly IScan scanService;
@@ -53,7 +57,7 @@ namespace HandBrakeWPF.Services
         /// <param name="windowManager">
         /// The window Manager.
         /// </param>
-        public PrePostActionService(IQueueProcessor queueProcessor, IUserSettingService userSettingService, IWindowManager windowManager, IScan scanService)
+        public PrePostActionService(IQueueService queueProcessor, IUserSettingService userSettingService, IWindowManager windowManager, IScan scanService)
         {
             this.queueProcessor = queueProcessor;
             this.userSettingService = userSettingService;
@@ -135,50 +139,52 @@ namespace HandBrakeWPF.Services
                 this.PlayWhenDoneSound();
             }
 
-            if (this.userSettingService.GetUserSetting<string>(UserSettingConstants.WhenCompleteAction) == "Do nothing")
+            if (this.userSettingService.GetUserSetting<int>(UserSettingConstants.WhenCompleteAction) == (int)WhenDone.DoNothing)
             {
                 return;
             }
 
             // Give the user the ability to cancel the shutdown. Default 60 second timer.
-            ICountdownAlertViewModel titleSpecificView = IoC.Get<ICountdownAlertViewModel>();
-            Execute.OnUIThread(
-                () =>
+            bool isCancelled = false;
+            if (!this.userSettingService.GetUserSetting<bool>(UserSettingConstants.WhenDonePerformActionImmediately))
+            {
+                ICountdownAlertViewModel titleSpecificView = IoC.Get<ICountdownAlertViewModel>();
+                Execute.OnUIThread(
+                    () =>
                     {
-                        titleSpecificView.SetAction(this.userSettingService.GetUserSetting<string>(UserSettingConstants.WhenCompleteAction));
+                        titleSpecificView.SetAction((WhenDone)this.userSettingService.GetUserSetting<int>(UserSettingConstants.WhenCompleteAction));
                         this.windowManager.ShowDialog(titleSpecificView);
+                        isCancelled = titleSpecificView.IsCancelled;
                     });
+            }
+
+            if (!isCancelled)
+            {
+                this.ServiceLogMessage(string.Format("Performing 'When Done' Action: {0}", this.userSettingService.GetUserSetting<int>(UserSettingConstants.WhenCompleteAction)));
 
-            if (!titleSpecificView.IsCancelled)
-            {               
                 // Do something when the encode ends.
-                switch (this.userSettingService.GetUserSetting<string>(UserSettingConstants.WhenCompleteAction))
+                switch ((WhenDone)this.userSettingService.GetUserSetting<int>(UserSettingConstants.WhenCompleteAction))
                 {
-                    case "Shutdown":
-                    case "Herunterfahren":
+                    case WhenDone.Shutdown:
                         ProcessStartInfo shutdown = new ProcessStartInfo("Shutdown", "-s -t 60");
                         shutdown.UseShellExecute = false;
                         Process.Start(shutdown);
                         Execute.OnUIThread(() => System.Windows.Application.Current.Shutdown());
                         break;
-                    case "Log off":
-                    case "Ausloggen":
+                    case WhenDone.LogOff:
                         this.scanService.Dispose();
                         Win32.ExitWindowsEx(0, 0);
                         break;
-                    case "Suspend":
+                    case WhenDone.Sleep:
                         Application.SetSuspendState(PowerState.Suspend, true, true);
                         break;
-                    case "Hibernate":
-                    case "Ruhezustand":
+                    case WhenDone.Hibernate:
                         Application.SetSuspendState(PowerState.Hibernate, true, true);
                         break;
-                    case "Lock System":
-                    case "System sperren":
+                    case WhenDone.LockSystem:
                         Win32.LockWorkStation();
                         break;
-                    case "Quit HandBrake":
-                    case "HandBrake beenden":
+                    case WhenDone.QuickHandBrake:
                         Execute.OnUIThread(() => System.Windows.Application.Current.Shutdown());
                         break;
                 }
@@ -200,10 +206,13 @@ namespace HandBrakeWPF.Services
                     "{0} \"{1}\"", 
                     this.userSettingService.GetUserSetting<string>(UserSettingConstants.SendFileToArgs), 
                     file);
-                var vlc =
+                var destination =
                     new ProcessStartInfo(
                         this.userSettingService.GetUserSetting<string>(UserSettingConstants.SendFileTo), args);
-                Process.Start(vlc);
+
+                this.ServiceLogMessage(string.Format("Sending output file to: {0}, with arguments: {1} ", destination, args));
+
+                Process.Start(destination);
             }
         }
 
@@ -212,11 +221,22 @@ namespace HandBrakeWPF.Services
             string filePath = this.userSettingService.GetUserSetting<string>(UserSettingConstants.WhenDoneAudioFile);
             if (!string.IsNullOrEmpty(filePath) && File.Exists(filePath))
             {
+                this.ServiceLogMessage("Playing Sound: " + filePath);
                 var uri = new Uri(filePath, UriKind.RelativeOrAbsolute);
                 var player = new MediaPlayer();
+                player.MediaFailed += (object sender, ExceptionEventArgs e) => { this.ServiceLogMessage(e?.ToString()); };
                 player.Open(uri);
                 player.Play();
             }
+            else
+            {
+                this.ServiceLogMessage("Unable to play sound. Reason: File not found!");
+            }
+        }
+
+        private void ServiceLogMessage(string message)
+        {
+            this.log.LogMessage(string.Format("# {1}{0}", Environment.NewLine, message), LogMessageType.ScanOrEncode, LogLevel.Info);
         }
     }
 }
