@@ -21,6 +21,7 @@ namespace HandBrakeWPF.Services.Presets
 
     using HandBrake.Interop.Interop;
     using HandBrake.Interop.Interop.Json.Presets;
+    using HandBrake.Interop.Interop.Model;
     using HandBrake.Interop.Model;
     using HandBrake.Interop.Utilities;
 
@@ -29,6 +30,9 @@ namespace HandBrakeWPF.Services.Presets
     using HandBrakeWPF.Properties;
     using HandBrakeWPF.Services.Encode.Model.Models;
     using HandBrakeWPF.Services.Interfaces;
+    using HandBrakeWPF.Services.Logging;
+    using HandBrakeWPF.Services.Logging.Interfaces;
+    using HandBrakeWPF.Services.Logging.Model;
     using HandBrakeWPF.Services.Presets.Factories;
     using HandBrakeWPF.Services.Presets.Interfaces;
     using HandBrakeWPF.Services.Presets.Model;
@@ -43,10 +47,6 @@ namespace HandBrakeWPF.Services.Presets
     /// </summary>
     public class PresetService : IPresetService
     {
-        // TODO Strip out the error handling from this service and let upstream UI layer handle it.
-
-        #region Private Variables
-
         public const int ForcePresetReset = 3;
         public static string UserPresetCatgoryName = "Custom Presets";
         private readonly string presetFile = Path.Combine(DirectoryUtilities.GetUserStoragePath(VersionHelper.IsNightly()), "presets.json");
@@ -55,8 +55,8 @@ namespace HandBrakeWPF.Services.Presets
         private readonly List<Preset> flatPresetList = new List<Preset>();
         private readonly IErrorService errorService;
         private readonly IUserSettingService userSettingService;
+        private ILog log = LogService.GetLogger();
 
-        #endregion
 
         /// <summary>
         /// Initializes a new instance of the <see cref="PresetService"/> class.
@@ -95,8 +95,6 @@ namespace HandBrakeWPF.Services.Presets
             }
         }
 
-        #region Public Methods
-
         /// <summary>
         /// The load.
         /// </summary>
@@ -177,7 +175,7 @@ namespace HandBrakeWPF.Services.Presets
                 PresetTransportContainer container = null;
                 try
                 {
-                    container = HandBrakePresetService.GetPresetFromFile(filename);
+                    container = HandBrakePresetService.GetPresetsFromFile(filename);
                 }
                 catch (Exception exc)
                 {
@@ -194,6 +192,7 @@ namespace HandBrakeWPF.Services.Presets
                 // HBPreset Handling
                 if (container.PresetList != null)
                 {
+                    bool containsBuildInPreset = false;
                     foreach (var objectPreset in container.PresetList)
                     {
                         PresetCategory category = JsonConvert.DeserializeObject<PresetCategory>(objectPreset.ToString());
@@ -202,10 +201,14 @@ namespace HandBrakeWPF.Services.Presets
                             foreach (HBPreset hbPreset in category.ChildrenArray)
                             {
                                 Preset preset = this.ConvertHbPreset(hbPreset);
-                                if (preset != null)
+                                if (preset != null && !preset.IsBuildIn)
                                 {
                                     this.AddOrUpdateImportedPreset(preset);
                                 }
+                                else
+                                {
+                                    containsBuildInPreset = true;
+                                }
                             }
                         }
                         else
@@ -214,13 +217,26 @@ namespace HandBrakeWPF.Services.Presets
                             if (hbPreset != null)
                             {
                                 Preset preset = this.ConvertHbPreset(hbPreset);
-                                if (preset != null)
+                                if (preset != null && !preset.IsBuildIn)
                                 {
                                     this.AddOrUpdateImportedPreset(preset);
                                 }
+                                else
+                                {
+                                    containsBuildInPreset = true;
+                                }
                             }
                         }
                     }
+
+                    if (containsBuildInPreset)
+                    {
+                        this.errorService.ShowMessageBox(
+                            Properties.Resources.PresetService_ImportingBuiltInWarning,
+                            Properties.Resources.Warning,
+                            MessageBoxButton.OK,
+                            MessageBoxImage.Warning);
+                    }
                 }
             }
         }
@@ -487,6 +503,7 @@ namespace HandBrakeWPF.Services.Presets
             // Verify we have presets.
             if (this.presets.Count == 0)
             {
+                this.ServiceLogMessage("Failed to load built-in presets.");
                 throw new GeneralApplicationException("Failed to load built-in presets.", "Restarting HandBrake may resolve this issue", null);
             }
 
@@ -601,66 +618,48 @@ namespace HandBrakeWPF.Services.Presets
             return categoriesList;
         }
 
-        #endregion
-
-        #region Private Helpers
-
         /// <summary>
-        /// Recover from a corrupted preset file
-        /// Add .old to the current filename, and delete the current file.
+        /// Archive the presets file without deleting it.
         /// </summary>
         /// <param name="file">
-        /// The broken presets file.
+        /// The filename to archive
+        /// </param>
+        /// <param name="delete">
+        /// True will delete the current presets file.
         /// </param>
         /// <returns>
-        /// The <see cref="string"/>.
+        /// The archived filename
         /// </returns>
-        private string RecoverFromCorruptedPresetFile(string file)
+        private string ArchivePresetFile(string file, bool delete)
         {
             try
             {
                 // Recover from Error.
-                string disabledFile = string.Format("{0}.{1}", file, GeneralUtilities.ProcessId);
+                PresetVersion version = HandBrakePresetService.GetCurrentPresetVersion();
+                string archiveFile = string.Format("{0}.{1}_{2}_{3}.archive", file, version.Major, version.Minor, version.Micro);
                 if (File.Exists(file))
                 {
-                    File.Move(file, disabledFile);
-                    if (File.Exists(file))
+                    int counter = 0;
+                    while (File.Exists(archiveFile))
+                    {
+                        counter = counter + 1;
+                        string appendedNumber = string.Format("({0})", counter);
+                        archiveFile = string.Format("{0}.{1}_{2}_{3} {4}.archive", file, version.Major, version.Minor, version.Micro, appendedNumber);
+                    }
+
+                    File.Copy(file, archiveFile);
+
+                    if (delete)
                     {
                         File.Delete(file);
                     }
                 }
 
-                return disabledFile;
-            }
-            catch (IOException)
-            {
-                // Give up
-            }
-
-            return "Sorry, the archiving failed.";
-        }
-
-        /// <summary>
-        /// Archive the presets file without deleting it.
-        /// </summary>
-        /// <param name="file">The filename to archive</param>
-        /// <returns>The archived filename</returns>
-        private string ArchivePresetFile(string file)
-        {
-            try
-            {
-                // Recover from Error.
-                string archiveFile = string.Format("{0}.{1}", file, GeneralUtilities.ProcessId);
-                if (File.Exists(file))
-                {
-                    File.Copy(file, archiveFile);
-                }
-
                 return archiveFile;
             }
-            catch (IOException)
+            catch (IOException e)
             {
-                // Give up
+                this.ServiceLogMessage(e.ToString());
             }
 
             return "Sorry, the archiving failed.";
@@ -686,22 +685,20 @@ namespace HandBrakeWPF.Services.Presets
 
                 // Otherwise, we already have a file, so lets try load it.
                 PresetTransportContainer container = null;
-                using (StreamReader reader = new StreamReader(this.presetFile))
+                try
                 {
-                    try
-                    {
-                        container = JsonConvert.DeserializeObject<PresetTransportContainer>(reader.ReadToEnd());
-                    }
-                    catch (Exception exc)
-                    {
-                        Debug.WriteLine("Failed to parse presets file: " + exc);
-                    }
+                    container = HandBrakePresetService.GetPresetsFromFile(this.presetFile);
+                }
+                catch (Exception exc)
+                {
+                    this.ServiceLogMessage("Corrupted Presets File Detected: " + Environment.NewLine + exc);
                 }
 
                 // Sanity Check. Did the container deserialise.
-                if (container == null || container.PresetList == null)
+                if (container?.PresetList == null)
                 {
-                    string filename = this.RecoverFromCorruptedPresetFile(this.presetFile);
+                    this.ServiceLogMessage("Attempting Preset Recovery ...");
+                    string filename = this.ArchivePresetFile(this.presetFile, true);
                     this.errorService.ShowMessageBox(
                         Resources.PresetService_UnableToLoadPresets + filename,
                         Resources.PresetService_UnableToLoad,
@@ -709,32 +706,16 @@ namespace HandBrakeWPF.Services.Presets
                         MessageBoxImage.Exclamation);
 
                     this.UpdateBuiltInPresets();
+                    this.ServiceLogMessage("Recovery Completed!");
                     return; // Update built-in presets stores the presets locally, so just return.
                 }
 
-                // Version Check
-                // If we have old presets, or the container wasn't parseable, or we have a version mismatch, backup the user preset file 
-                // incase something goes wrong and reset built-in presets, then re-save.
-                bool ignoreBuildIn = false;
-                if (container.VersionMajor != Constants.PresetVersionMajor || container.VersionMinor != Constants.PresetVersionMinor || container.VersionMicro != Constants.PresetVersionMicro)
-                {
-                    string fileName = this.ArchivePresetFile(this.presetFile);
-                    this.errorService.ShowMessageBox(
-                        Resources.PresetService_PresetsOutOfDate
-                        + Environment.NewLine + Environment.NewLine + Resources.PresetService_ArchiveFile + fileName,
-                        Resources.PresetService_UnableToLoad,
-                        MessageBoxButton.OK,
-                        MessageBoxImage.Information);
-                    this.UpdateBuiltInPresets(); // Update built-in presets stores the presets locally, so just return.
-                    ignoreBuildIn = true;
-                }
-
                 // Force Upgrade of presets
-                if (this.userSettingService.GetUserSetting<int>(UserSettingConstants.ForcePresetReset, typeof(int)) < ForcePresetReset)
+                if (this.userSettingService.GetUserSetting<int>(UserSettingConstants.ForcePresetReset) < ForcePresetReset)
                 {
                     this.userSettingService.SetUserSetting(UserSettingConstants.ForcePresetReset, ForcePresetReset);
 
-                    string fileName = this.ArchivePresetFile(this.presetFile);
+                    string fileName = this.ArchivePresetFile(this.presetFile, true);
                     this.errorService.ShowMessageBox(
                         Resources.Presets_PresetForceReset
                         + Environment.NewLine + Environment.NewLine + Resources.PresetService_ArchiveFile + fileName,
@@ -745,17 +726,17 @@ namespace HandBrakeWPF.Services.Presets
                     return;
                 }
 
-                this.ProcessPresetList(container, ignoreBuildIn);
+                this.ProcessPresetList(container);
             }
             catch (Exception ex)
             {
-                Debug.WriteLine(ex);
-                this.RecoverFromCorruptedPresetFile(this.presetFile);
+                this.ServiceLogMessage(ex.ToString());
+                this.ArchivePresetFile(this.presetFile, true);
                 this.UpdateBuiltInPresets();
             }
         }
 
-        private void ProcessPresetList(PresetTransportContainer container, bool ignoreOldBuiltIn)
+        private void ProcessPresetList(PresetTransportContainer container)
         {
             // The presets file loaded was OK, so process it.
             foreach (var item in container.PresetList)
@@ -770,11 +751,6 @@ namespace HandBrakeWPF.Services.Presets
                     {
                         Preset preset = JsonPresetFactory.ImportPreset(hbpreset);
 
-                        if (preset.IsBuildIn && ignoreOldBuiltIn)
-                        {
-                            continue;
-                        }
-
                         // Migration
                         preset.Category = category.PresetName == "User Presets" ? UserPresetCatgoryName : category.PresetName;
                         preset.IsBuildIn = hbpreset.Type == 0;
@@ -809,7 +785,6 @@ namespace HandBrakeWPF.Services.Presets
                     this.Add(preset, true);
                 }
             }
-
         }
 
         /// <summary>
@@ -830,19 +805,17 @@ namespace HandBrakeWPF.Services.Presets
                 Dictionary<string, PresetCategory> presetCategories = new Dictionary<string, PresetCategory>();
                 List<HBPreset> uncategorisedPresets = new List<HBPreset>();
 
+                // Handle User Presets.
+                this.HandlePresetListsForSave(this.flatPresetList.Where(o => !o.IsBuildIn).ToList(), presetCategories, uncategorisedPresets);
+
                 // Handle Built-in Presets
                 this.HandlePresetListsForSave(this.flatPresetList.Where(o => o.IsBuildIn).ToList(), presetCategories, uncategorisedPresets);
 
-                // Handle User Presets.
-                this.HandlePresetListsForSave(this.flatPresetList.Where(o => !o.IsBuildIn).ToList(), presetCategories, uncategorisedPresets);
-    
                 // Wrap the categories in a container. 
                 JsonSerializerSettings settings = new JsonSerializerSettings { MissingMemberHandling = MissingMemberHandling.Ignore };
-                PresetTransportContainer container = new PresetTransportContainer(
-                                                             Constants.PresetVersionMajor,
-                                                             Constants.PresetVersionMinor,
-                                                             Constants.PresetVersionMicro)
-                                                         { PresetList = new List<object>() };
+
+                PresetVersion presetVersion = HandBrakePresetService.GetCurrentPresetVersion();
+                PresetTransportContainer container = new PresetTransportContainer(presetVersion.Major, presetVersion.Minor, presetVersion.Micro) { PresetList = new List<object>() };
                 container.PresetList.AddRange(presetCategories.Values);
                 container.PresetList.AddRange(uncategorisedPresets);
 
@@ -858,7 +831,6 @@ namespace HandBrakeWPF.Services.Presets
             }
             catch (Exception exc)
             {
-                Debug.WriteLine(exc);
                 throw new GeneralApplicationException("Unable to write to the presets file.", "The details section below may indicate why this error has occurred.", exc);
             }
         }
@@ -937,6 +909,9 @@ namespace HandBrakeWPF.Services.Presets
             }
         }
 
-        #endregion
+        protected void ServiceLogMessage(string message)
+        {
+            this.log.LogMessage(string.Format("Preset Service: {0}{1}{0}", Environment.NewLine, message), LogMessageType.Application, LogLevel.Info);
+        }
     }
 }
\ No newline at end of file
