@@ -88,11 +88,11 @@ namespace HandBrakeWPF.Services
         /// <returns>
         /// The user setting
         /// </returns>
-        public T GetUserSetting<T>(string name, Type conversionType = null)
+        public T GetUserSetting<T>(string name)
         {
             if (this.userSettings.ContainsKey(name))
             {
-                if (conversionType != null && typeof(int) == conversionType)
+                if (typeof(T) == typeof(int))
                 {
                     object storedValue = this.userSettings[name];
                     object converted = storedValue?.ToString().ToInt();
@@ -176,7 +176,7 @@ namespace HandBrakeWPF.Services
                     using (StreamReader reader = new StreamReader(this.settingsFile))
                     {
                         string appSettings = reader.ReadToEnd();
-                        Dictionary<string, object> deserialisedSettings = JsonConvert.DeserializeObject< Dictionary<string, object>>(appSettings);
+                        Dictionary<string, object> deserialisedSettings = JsonConvert.DeserializeObject<Dictionary<string, object>>(appSettings);
 
                         this.userSettings = deserialisedSettings;
                     }
@@ -212,7 +212,6 @@ namespace HandBrakeWPF.Services
                 }
 
                 // Legacy Settings forced Reset.
-                this.userSettings[UserSettingConstants.ShowAdvancedTab] = false;
                 this.userSettings[UserSettingConstants.ScalingMode] = VideoScaler.Lanczos;
             }
             catch (Exception exc)
