@@ -14,8 +14,6 @@ namespace HandBrakeWPF
     /// </summary>
     public class UserSettingConstants
     {
-        #region Constants and Fields
-
         public const string AutoNameFormat = "autoNameFormat";
         public const string AutoNamePath = "autoNamePath";
         public const string AutoNameRemoveUnderscore = "AutoNameRemoveUnderscore";
@@ -31,15 +29,15 @@ namespace HandBrakeWPF
         public const string VLCPath = "VLC_Path";
         public const string InstanceId = "InstanceId";
         public const string X264Step = "X264Step";
-        public const string ShowAdvancedTab = "ShowAdvancedTab";
         public const string LastPreviewDuration = "LastPreviewDuration";
-        public const string WhenCompleteAction = "WhenCompleteAction";
+        public const string WhenCompleteAction = "WhenCompletePerformAction";
         public const string SendFile = "SendFile";
         public const string SendFileTo = "SendFileTo";
         public const string SendFileToArgs = "SendFileToArgs";
         public const string PreventSleep = "PreventSleep";
         public const string PauseOnLowDiskspace = "PauseOnLowDiskspace";
-        public const string PauseOnLowDiskspaceLevel = "LowDiskSpaceWarningLevelInBytes";
+        public const string PauseQueueOnLowDiskspaceLevel = "LowDiskSpaceWarningLevelInBytes";
+        public const string PauseEncodeOnLowDiskspaceLevel = "LowDiskSpaceEncodePauseLevelInBytes";
         public const string RemovePunctuation = "RemovePunctuation";
         public const string ShowPresetPanel = "ShowPresetPanelOption";
         public const string ResetWhenDoneAction = "ResetWhenDoneAction";
@@ -50,12 +48,11 @@ namespace HandBrakeWPF
         public const string PreviewScanCount = "previewScanCount";
         public const string Verbosity = "Verbosity";
         public const string MinScanDuration = "MinTitleScanDuration";
-        public const string ProcessPriority = "ProcessPriority";
+        public const string ProcessPriorityInt = "ProcessPriorityInt";
         public const string SaveLogToCopyDirectory = "SaveLogToCopyDirectory";
         public const string SaveLogWithVideo = "SaveLogWithVideo";
         public const string SaveLogCopyDirectory = "SaveLogCopyDirectory";
         public const string ClearCompletedFromQueue = "ClearCompletedFromQueue";
-        public const string ShowQueueInline = "ShowQueueInline";
         public const string ForcePresetReset = "ForcePresetReset";
         public const string PresetExpandedStateList = "PresetExpandedStateList";
         public const string ShowStatusInTitleBar = "ShowStatusInTitleBar";
@@ -68,11 +65,14 @@ namespace HandBrakeWPF
         public const string EnableQuickSyncEncoding = "EnableQuickSyncEncoding";
         public const string EnableVceEncoder = "EnableVceEncoder";
         public const string EnableNvencEncoder = "EnableNvencEncoder";
-        public const string ShowExperimentalQueue = "ShowExperimentalQueue";
         public const string UiLanguage = "UiLanguage";
         public const string ShowAddAllToQueue = "ShowAddAllToQueue";
         public const string ShowAddSelectionToQueue = "ShowAddSelectionToQueue";
-
-        #endregion
+        public const string FileOverwriteBehaviour = "FileOverwriteBehaviour";
+        public const string AutonameFileCollisionBehaviour = "AutonameFileCollisionBehaviour";
+        public const string AutonameFilePrePostString = "AutonameFilePrePostString";
+        public const string WhenDonePerformActionImmediately = "WhenDonePerformActionImmediately";
+        public const string UseDarkTheme = "UseDarkTheme";
+        public const string PreviewRotationFlip = "PreviewRotationFlip";
     }
 }
\ No newline at end of file
