@@ -29,6 +29,7 @@ namespace HandBrakeWPF.ViewModels
     using HandBrakeWPF.Services.Scan.Model;
     using HandBrakeWPF.Utilities;
     using HandBrakeWPF.ViewModels.Interfaces;
+    using HandBrakeWPF.Views;
 
     using AudioEncoder = HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder;
     using AudioTrack = HandBrakeWPF.Services.Encode.Model.Models.AudioTrack;
@@ -209,6 +210,14 @@ namespace HandBrakeWPF.ViewModels
                 }
             }
 
+            if (this.Task.OutputFormat == OutputFormat.WebM)
+            {
+                foreach (AudioTrack track in this.Task.AudioTracks.Where(track => track.Encoder != AudioEncoder.Vorbis && track.Encoder != AudioEncoder.Opus))
+                {
+                    track.Encoder = AudioEncoder.Vorbis;
+                }
+            }
+
             this.AudioDefaultsViewModel.RefreshTask();
         }
 
@@ -217,8 +226,7 @@ namespace HandBrakeWPF.ViewModels
         /// </summary>
         public void ShowAudioDefaults()
         {
-            IPopupWindowViewModel popup = new PopupWindowViewModel(this.AudioDefaultsViewModel, Resources.Preset_AudioDefaults_Title, Resources.AudioView_AudioDefaultsDescription);
-            if (this.windowManager.ShowDialog(popup) == true)
+            if (this.windowManager.ShowDialog(this.AudioDefaultsViewModel) == true)
             {
                 this.OnTabStatusChanged(null);
             }
@@ -449,7 +457,7 @@ namespace HandBrakeWPF.ViewModels
 
         private bool CanAddTrack(AudioBehaviourTrack track, Audio sourceTrack, AudioEncoder fallback)
         {
-            if (fallback == AudioEncoder.None)
+            if (fallback == AudioEncoder.None && track != null)
             {
                 HBAudioEncoder encoderInfo = HandBrakeEncoderHelpers.GetAudioEncoder(EnumHelper<AudioEncoder>.GetShortName(track.Encoder));
                 if (track.IsPassthru && (sourceTrack.Codec & encoderInfo.Id) == 0)
@@ -522,7 +530,7 @@ namespace HandBrakeWPF.ViewModels
 
             foreach (Audio sourceTrack in this.GetSelectedLanguagesTracks())
             {
-                // Step 2: Check if the track list already contrains this track
+                // Step 2: Check if the track list already contains this track
                 bool found = this.Task.AudioTracks.Any(audioTrack => Equals(audioTrack.ScannedTrack, sourceTrack));
                 if (!found)
                 {
@@ -623,10 +631,14 @@ namespace HandBrakeWPF.ViewModels
                 ? LanguageUtilities.GetIsoCodes()
                 : LanguageUtilities.GetLanguageCodes(this.AudioBehaviours.SelectedLangauges.ToArray());
 
-            List<Audio> availableTracks =
-                this.SourceTracks.Where(audio => iso6392Codes.Contains(audio.LanguageCode.Trim())).ToList();
 
-            return availableTracks;
+            List<Audio> orderedTracks = new List<Audio>();
+            foreach (string code in iso6392Codes)
+            {
+                orderedTracks.AddRange(this.SourceTracks.Where(audio => audio.LanguageCode == code));
+            }
+
+            return orderedTracks;
         }
 
         #endregion
