@@ -16,6 +16,7 @@ namespace HandBrakeWPF.ViewModels
     using System.IO;
     using System.Linq;
     using System.Windows;
+    using System.Windows.Media;
 
     using Caliburn.Micro;
 
@@ -24,6 +25,7 @@ namespace HandBrakeWPF.ViewModels
     using HandBrake.Interop.Utilities;
 
     using HandBrakeWPF.Model;
+    using HandBrakeWPF.Model.Options;
     using HandBrakeWPF.Properties;
     using HandBrakeWPF.Services.Interfaces;
     using HandBrakeWPF.Utilities;
@@ -53,8 +55,7 @@ namespace HandBrakeWPF.ViewModels
         private string autonameFormat;
         private bool changeToTitleCase;
         private bool checkForUpdates;
-        private BindingList<string> checkForUpdatesFrequencies = new BindingList<string>();
-        private int checkForUpdatesFrequency;
+        private UpdateCheck checkForUpdatesFrequency;
         private bool clearOldOlgs;
         private BindingList<string> constantQualityGranularity = new BindingList<string>();
         private bool copyLogToEncodeDirectory;
@@ -64,22 +65,19 @@ namespace HandBrakeWPF.ViewModels
         private BindingList<int> logVerbosityOptions = new BindingList<int>();
         private long minLength;
         private bool minimiseToTray;
-        private BindingList<string> mp4ExtensionOptions = new BindingList<string>();
         private bool preventSleep;
         private BindingList<int> previewPicturesToScan = new BindingList<int>();
-        private BindingList<string> priorityLevelOptions = new BindingList<string>();
         private bool removeUnderscores;
         private string selectedGranulairty;
-        private int selectedMp4Extension;
+        private Mp4Behaviour selectedMp4Extension;
         private int selectedPreviewCount;
-        private string selectedPriority;
+        private ProcessPriority selectedPriority;
         private int selectedVerbosity;
         private bool sendFileAfterEncode;
         private string sendFileTo;
         private string sendFileToPath;
         private string vlcPath;
-        private string whenDone;
-        private BindingList<string> whenDoneOptions = new BindingList<string>();
+        private WhenDone whenDone;
         private bool clearQueueOnEncodeCompleted;
         private OptionsTab selectedTab;
         private string updateMessage;
@@ -89,7 +87,6 @@ namespace HandBrakeWPF.ViewModels
         private bool removePunctuation;
         private bool resetWhenDoneAction;
         private bool enableQuickSyncDecoding;
-        private bool showQueueInline;
         private bool pauseOnLowDiskspace;
         private long pauseOnLowDiskspaceLevel;
         private bool useQsvDecodeForNonQsvEnc;
@@ -101,9 +98,15 @@ namespace HandBrakeWPF.ViewModels
         private bool enableQuickSyncEncoding;
         private bool enableVceEncoder;    
         private bool enableNvencEncoder;
-        private bool showExperimentalQueue;
-
         private InterfaceLanguage selectedLanguage;
+        private bool showAddSelectionToQueue;
+        private bool showAddAllToQueue;
+        private int selectedOverwriteBehaviour;
+        private int selectedCollisionBehaviour;
+        private string prePostFilenameText;
+        private bool showPrePostFilenameBox;
+        private bool whenDonePerformActionImmediately;
+        private bool useDarkTheme;
 
         #endregion
 
@@ -134,7 +137,7 @@ namespace HandBrakeWPF.ViewModels
             this.OnLoad();
 
             this.SelectedTab = OptionsTab.General;
-            this.UpdateMessage = "Click 'Check for Updates' to check for new versions";
+            this.UpdateMessage = Resources.OptionsViewModel_CheckForUpdatesMsg;
         }
 
         #endregion
@@ -183,6 +186,8 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
+        public bool IsWindows10 => HandBrakeWPF.Utilities.SystemInfo.IsWindows10();
+
         #region General
 
         public BindingList<InterfaceLanguage> InterfaceLanguages
@@ -241,24 +246,18 @@ namespace HandBrakeWPF.ViewModels
         /// <summary>
         /// Gets or sets CheckForUpdatesFrequencies.
         /// </summary>
-        public BindingList<string> CheckForUpdatesFrequencies
+        public BindingList<UpdateCheck> CheckForUpdatesFrequencies
         {
             get
             {
-                return this.checkForUpdatesFrequencies;
-            }
-
-            set
-            {
-                this.checkForUpdatesFrequencies = value;
-                this.NotifyOfPropertyChange("CheckForUpdatesFrequencies");
+                return new BindingList<UpdateCheck>(EnumHelper<UpdateCheck>.GetEnumList().ToList());
             }
         }
 
         /// <summary>
         /// Gets or sets a value indicating whether CheckForUpdatesFrequency.
         /// </summary>
-        public int CheckForUpdatesFrequency
+        public UpdateCheck CheckForUpdatesFrequency
         {
             get
             {
@@ -268,7 +267,7 @@ namespace HandBrakeWPF.ViewModels
             set
             {
                 this.checkForUpdatesFrequency = value;
-                this.NotifyOfPropertyChange("CheckForUpdatesFrequency");
+                this.NotifyOfPropertyChange(() => this.CheckForUpdatesFrequency);
             }
         }
 
@@ -343,7 +342,7 @@ namespace HandBrakeWPF.ViewModels
         /// <summary>
         /// Gets or sets WhenDone.
         /// </summary>
-        public string WhenDone
+        public WhenDone WhenDone
         {
             get
             {
@@ -358,50 +357,24 @@ namespace HandBrakeWPF.ViewModels
         }
 
         /// <summary>
-        /// Gets or sets WhenDoneOptions.
+        /// Gets WhenDoneOptions.
         /// </summary>
-        public BindingList<string> WhenDoneOptions
+        public BindingList<WhenDone> WhenDoneOptions
         {
             get
             {
-                return this.whenDoneOptions;
-            }
-
-            set
-            {
-                this.whenDoneOptions = value;
-                this.NotifyOfPropertyChange("WhenDoneOptions");
+                return new BindingList<WhenDone>(EnumHelper<WhenDone>.GetEnumList().ToList());
             }
         }
 
-        /// <summary>
-        /// Gets or sets a value indicating whether show queue inline.
-        /// </summary>
-        public bool ShowQueueInline
+        public bool WhenDonePerformActionImmediately
         {
-            get
-            {
-                return this.showQueueInline;
-            }
+            get => this.whenDonePerformActionImmediately;
             set
             {
-                if (value == this.showQueueInline)
-                {
-                    return;
-                }
-                this.showQueueInline = value;
-                this.NotifyOfPropertyChange(() => this.ShowQueueInline);
-            }
-        }
-
-        public bool ShowExperimentalQueue
-        {
-            get => this.showExperimentalQueue;
-            set
-            {
-                if (value == this.showExperimentalQueue) return;
-                this.showExperimentalQueue = value;
-                this.NotifyOfPropertyChange(() => this.ShowExperimentalQueue);
+                if (value == this.whenDonePerformActionImmediately) return;
+                this.whenDonePerformActionImmediately = value;
+                this.NotifyOfPropertyChange(() => this.WhenDonePerformActionImmediately);
             }
         }
 
@@ -492,6 +465,39 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
+        public bool ShowAddSelectionToQueue
+        {
+            get => this.showAddSelectionToQueue;
+            set
+            {
+                if (value == this.showAddSelectionToQueue) return;
+                this.showAddSelectionToQueue = value;
+                this.NotifyOfPropertyChange(() => this.ShowAddSelectionToQueue);
+            }
+        }
+
+        public bool ShowAddAllToQueue
+        {
+            get => this.showAddAllToQueue;
+            set
+            {
+                if (value == this.showAddAllToQueue) return;
+                this.showAddAllToQueue = value;
+                this.NotifyOfPropertyChange(() => this.ShowAddAllToQueue);
+            }
+        }
+
+        public bool UseDarkTheme
+        {
+            get => this.useDarkTheme;
+            set
+            {
+                if (value == this.useDarkTheme) return;
+                this.useDarkTheme = value;
+                this.NotifyOfPropertyChange(() => this.UseDarkTheme);
+            }
+        }
+
         #endregion
 
         #region Output Files
@@ -568,23 +574,6 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        /// Gets or sets Mp4ExtensionOptions.
-        /// </summary>
-        public BindingList<string> Mp4ExtensionOptions
-        {
-            get
-            {
-                return this.mp4ExtensionOptions;
-            }
-
-            set
-            {
-                this.mp4ExtensionOptions = value;
-                this.NotifyOfPropertyChange("Mp4ExtensionOptions");
-            }
-        }
-
         /// <summary>
         /// Gets or sets a value indicating whether RemoveUnderscores.
         /// </summary>
@@ -602,10 +591,18 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
+        public BindingList<Mp4Behaviour> Mp4ExtensionOptions
+        {
+            get
+            {
+                return new BindingList<Mp4Behaviour>(EnumHelper<Mp4Behaviour>.GetEnumList().ToList());
+            }
+        }
+
         /// <summary>
         /// Gets or sets SelectedMp4Extension.
         /// </summary>
-        public int SelectedMp4Extension
+        public Mp4Behaviour SelectedMp4Extension
         {
             get
             {
@@ -615,7 +612,7 @@ namespace HandBrakeWPF.ViewModels
             set
             {
                 this.selectedMp4Extension = value;
-                this.NotifyOfPropertyChange("SelectedMp4Extension");
+                this.NotifyOfPropertyChange(() => this.SelectedMp4Extension);
             }
         }
 
@@ -635,6 +632,62 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
+        public BindingList<FileOverwriteBehaviour> FileOverwriteBehaviourList { get; set; }
+
+        public int SelectedOverwriteBehaviour
+        {
+            get => this.selectedOverwriteBehaviour;
+            set
+            {
+                if (value == this.selectedOverwriteBehaviour) return;
+                this.selectedOverwriteBehaviour = value;
+                this.NotifyOfPropertyChange(() => this.SelectedOverwriteBehaviour);
+            }
+        }
+
+        public BindingList<AutonameFileCollisionBehaviour> AutonameFileCollisionBehaviours { get; set; }
+
+        public int SelectedCollisionBehaviour
+        {
+            get => this.selectedCollisionBehaviour;
+            set
+            {
+                if (value == this.selectedCollisionBehaviour) return;
+                this.selectedCollisionBehaviour = value;
+
+                this.ShowPrePostFilenameBox = this.selectedCollisionBehaviour >= 1;
+
+                this.NotifyOfPropertyChange(() => this.SelectedCollisionBehaviour);
+            }
+        }
+
+        public string PrePostFilenameText
+        {
+            get => this.prePostFilenameText;
+            set
+            {
+                if (value == this.prePostFilenameText) return;
+
+                if (this.IsValidAutonameFormat(value, false))
+                {
+                    this.prePostFilenameText = value;
+                }
+
+                this.NotifyOfPropertyChange(() => this.PrePostFilenameText);
+            }
+        }
+
+        public bool ShowPrePostFilenameBox
+        {
+            get => this.showPrePostFilenameBox;
+            set
+            {
+                if (value == this.showPrePostFilenameBox) return;
+                this.showPrePostFilenameBox = value;
+                this.NotifyOfPropertyChange(() => this.ShowPrePostFilenameBox);
+            }
+        }
+
         #endregion
 
         #region Preview
@@ -779,20 +832,11 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        /// Gets or sets PriorityLevelOptions.
-        /// </summary>
-        public BindingList<string> PriorityLevelOptions
+        public BindingList<ProcessPriority> PriorityLevelOptions
         {
             get
             {
-                return this.priorityLevelOptions;
-            }
-
-            set
-            {
-                this.priorityLevelOptions = value;
-                this.NotifyOfPropertyChange("PriorityLevelOptions");
+                return new BindingList<ProcessPriority>(EnumHelper<ProcessPriority>.GetEnumList().ToList());
             }
         }
 
@@ -816,7 +860,7 @@ namespace HandBrakeWPF.ViewModels
         /// <summary>
         /// Gets or sets SelectedPriority.
         /// </summary>
-        public string SelectedPriority
+        public ProcessPriority SelectedPriority
         {
             get
             {
@@ -831,19 +875,19 @@ namespace HandBrakeWPF.ViewModels
                 // Set the Process Priority
                 switch (value)
                 {
-                    case "Realtime":
-                        Process.GetCurrentProcess().PriorityClass = ProcessPriorityClass.RealTime;
-                        break;
-                    case "High":
+                    case ProcessPriority.High:
                         Process.GetCurrentProcess().PriorityClass = ProcessPriorityClass.High;
                         break;
-                    case "Above Normal":
+                    case ProcessPriority.AboveNormal:
                         Process.GetCurrentProcess().PriorityClass = ProcessPriorityClass.AboveNormal;
                         break;
-                    case "Normal":
+                    case ProcessPriority.Normal:
                         Process.GetCurrentProcess().PriorityClass = ProcessPriorityClass.Normal;
                         break;
-                    case "Low":
+                    case ProcessPriority.BelowNormal:
+                        Process.GetCurrentProcess().PriorityClass = ProcessPriorityClass.BelowNormal;
+                        break;
+                    case ProcessPriority.Low:
                         Process.GetCurrentProcess().PriorityClass = ProcessPriorityClass.Idle;
                         break;
                     default:
@@ -1136,7 +1180,7 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        public bool IsHardwareFallbackMode => HandBrakeUtils.IsUsingNoHardwareFallback();
+        public bool IsHardwareFallbackMode => HandBrakeUtils.IsInitNoHardware();
 
         #endregion
 
@@ -1326,6 +1370,31 @@ namespace HandBrakeWPF.ViewModels
                 this.WhenDoneAudioFile = Path.GetFileNameWithoutExtension(dialog.FileName);
                 this.WhenDoneAudioFileFullPath = dialog.FileName;
             }
+            else
+            {
+                this.WhenDoneAudioFile = null;
+                this.WhenDoneAudioFileFullPath = null;
+            }
+        }
+
+        public void PlayWhenDoneFile()
+        {
+            if (!string.IsNullOrEmpty(this.WhenDoneAudioFileFullPath) && File.Exists(this.WhenDoneAudioFileFullPath))
+            {
+                var uri = new Uri(this.WhenDoneAudioFileFullPath, UriKind.RelativeOrAbsolute);
+                var player = new MediaPlayer();
+                player.Open(uri);
+                player.Play();
+                player.MediaFailed += (object sender, ExceptionEventArgs e) => { Debug.WriteLine(e); };
+            }
+            else
+            {
+                this.errorService.ShowMessageBox(
+                    Resources.OptionsView_MediaFileNotSet,
+                    Resources.Error,
+                    MessageBoxButton.OK,
+                    MessageBoxImage.Error);
+            }
         }
 
         #endregion
@@ -1342,31 +1411,21 @@ namespace HandBrakeWPF.ViewModels
             this.SelectedLanguage = InterfaceLanguageUtilities.FindInterfaceLanguage(culture);
 
             this.CheckForUpdates = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.UpdateStatus);
+            this.CheckForUpdatesFrequency = (UpdateCheck)this.userSettingService.GetUserSetting<int>(UserSettingConstants.DaysBetweenUpdateCheck);
+            this.ShowStatusInTitleBar = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.ShowStatusInTitleBar);
+            this.ShowPreviewOnSummaryTab = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.ShowPreviewOnSummaryTab);
+            this.ShowAddAllToQueue = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.ShowAddAllToQueue);
+            this.ShowAddSelectionToQueue = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.ShowAddSelectionToQueue);
+            this.UseDarkTheme = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.UseDarkTheme);
 
-            // Days between update checks
-            this.checkForUpdatesFrequencies.Clear();
-            this.checkForUpdatesFrequencies.Add("Weekly");
-            this.checkForUpdatesFrequencies.Add("Monthly");
+            // #############################
+            // When Done
+            // #############################
 
-            this.CheckForUpdatesFrequency = this.userSettingService.GetUserSetting<int>(UserSettingConstants.DaysBetweenUpdateCheck, typeof(int));
-            if (this.CheckForUpdatesFrequency > 1)
-            {
-                this.CheckForUpdatesFrequency = 1;
-            }
-
-            // On Encode Completeion Action
-            this.whenDoneOptions.Clear();
-            this.whenDoneOptions.Add("Do nothing");
-            this.whenDoneOptions.Add("Shutdown");
-            this.whenDoneOptions.Add("Suspend");
-            this.whenDoneOptions.Add("Hibernate");
-            this.whenDoneOptions.Add("Lock System");
-            this.whenDoneOptions.Add("Log off");
-            this.whenDoneOptions.Add("Quit HandBrake");
-            this.WhenDone = userSettingService.GetUserSetting<string>("WhenCompleteAction");
+            this.WhenDone = (WhenDone)this.userSettingService.GetUserSetting<int>(UserSettingConstants.WhenCompleteAction);
             if (this.userSettingService.GetUserSetting<bool>(UserSettingConstants.ResetWhenDoneAction))
             {
-                this.WhenDone = "Do nothing";
+                this.WhenDone = WhenDone.DoNothing;
             }
 
             this.SendFileAfterEncode = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.SendFile);
@@ -1374,15 +1433,12 @@ namespace HandBrakeWPF.ViewModels
             this.SendFileToPath = this.userSettingService.GetUserSetting<string>(UserSettingConstants.SendFileTo) ?? string.Empty;
             this.Arguments = this.userSettingService.GetUserSetting<string>(UserSettingConstants.SendFileToArgs) ?? string.Empty;
             this.ResetWhenDoneAction = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.ResetWhenDoneAction);
-            this.ShowQueueInline = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.ShowQueueInline);
-            this.ShowStatusInTitleBar = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.ShowStatusInTitleBar);
-            this.ShowPreviewOnSummaryTab = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.ShowPreviewOnSummaryTab);
+            this.WhenDonePerformActionImmediately = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.WhenDonePerformActionImmediately);
             this.WhenDoneAudioFile = Path.GetFileNameWithoutExtension(this.userSettingService.GetUserSetting<string>(UserSettingConstants.WhenDoneAudioFile)) ?? string.Empty;
             this.WhenDoneAudioFileFullPath = this.userSettingService.GetUserSetting<string>(UserSettingConstants.WhenDoneAudioFile);
             this.PlaySoundWhenDone = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.PlaySoundWhenDone);
             this.PlaySoundWhenQueueDone = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.PlaySoundWhenQueueDone);
-            this.ShowExperimentalQueue = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.ShowExperimentalQueue);
-            
+
             // #############################
             // Output Settings
             // #############################
@@ -1400,11 +1456,7 @@ namespace HandBrakeWPF.ViewModels
             this.AutonameFormat = this.IsValidAutonameFormat(anf, true) ? anf : "{source}-{title}";
 
             // Use iPod/iTunes friendly .m4v extension for MP4 files.
-            this.mp4ExtensionOptions.Clear();
-            this.mp4ExtensionOptions.Add("Automatic");
-            this.mp4ExtensionOptions.Add("Always use MP4");
-            this.mp4ExtensionOptions.Add("Always use M4V");
-            this.SelectedMp4Extension = this.userSettingService.GetUserSetting<int>(UserSettingConstants.UseM4v, typeof(int));
+            this.SelectedMp4Extension = (Mp4Behaviour)this.userSettingService.GetUserSetting<int>(UserSettingConstants.UseM4v);
 
             // Remove Underscores
             this.RemoveUnderscores = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.AutoNameRemoveUnderscore);
@@ -1413,6 +1465,17 @@ namespace HandBrakeWPF.ViewModels
             this.ChangeToTitleCase = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.AutoNameTitleCase);
             this.RemovePunctuation = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.RemovePunctuation);
 
+            // File Overwrite
+            this.FileOverwriteBehaviourList = new BindingList<FileOverwriteBehaviour>();
+            this.FileOverwriteBehaviourList.Add(FileOverwriteBehaviour.Ask);
+            this.FileOverwriteBehaviourList.Add(FileOverwriteBehaviour.ForceOverwrite);
+            this.SelectedOverwriteBehaviour = this.userSettingService.GetUserSetting<int>(UserSettingConstants.FileOverwriteBehaviour);
+
+            // Collision behaviour
+            this.AutonameFileCollisionBehaviours = new BindingList<AutonameFileCollisionBehaviour>() { AutonameFileCollisionBehaviour.AppendNumber, AutonameFileCollisionBehaviour.Prefix, AutonameFileCollisionBehaviour.Postfix };
+            this.SelectedCollisionBehaviour = this.userSettingService.GetUserSetting<int>(UserSettingConstants.AutonameFileCollisionBehaviour);
+            this.PrePostFilenameText = this.userSettingService.GetUserSetting<string>(UserSettingConstants.AutonameFilePrePostString);
+
             // #############################
             // Picture Tab
             // #############################
@@ -1424,7 +1487,7 @@ namespace HandBrakeWPF.ViewModels
             // Video
             // #############################
             this.EnableQuickSyncDecoding = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.EnableQuickSyncDecoding);
-            this.SelectedScalingMode = this.userSettingService.GetUserSetting<VideoScaler>(UserSettingConstants.ScalingMode, typeof(int));
+            this.SelectedScalingMode = this.userSettingService.GetUserSetting<VideoScaler>(UserSettingConstants.ScalingMode);
             this.UseQSVDecodeForNonQSVEnc = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.UseQSVDecodeForNonQSVEnc);
 
             this.EnableQuickSyncEncoding = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.EnableQuickSyncEncoding);
@@ -1434,26 +1497,18 @@ namespace HandBrakeWPF.ViewModels
             // #############################
             // CLI
             // #############################
-
-            // Priority level for encodes
-            this.priorityLevelOptions.Clear();
-            this.priorityLevelOptions.Add("High");
-            this.priorityLevelOptions.Add("Above Normal");
-            this.priorityLevelOptions.Add("Normal");
-            this.priorityLevelOptions.Add("Below Normal");
-            this.priorityLevelOptions.Add("Low");
-            this.SelectedPriority = userSettingService.GetUserSetting<string>(UserSettingConstants.ProcessPriority);
+            this.SelectedPriority = (ProcessPriority)userSettingService.GetUserSetting<int>(UserSettingConstants.ProcessPriorityInt);
 
             this.PreventSleep = userSettingService.GetUserSetting<bool>(UserSettingConstants.PreventSleep);
             this.PauseOnLowDiskspace = userSettingService.GetUserSetting<bool>(UserSettingConstants.PauseOnLowDiskspace);
-            this.PauseOnLowDiskspaceLevel = this.userSettingService.GetUserSetting<long>(UserSettingConstants.PauseOnLowDiskspaceLevel);
+            this.PauseOnLowDiskspaceLevel = this.userSettingService.GetUserSetting<long>(UserSettingConstants.PauseQueueOnLowDiskspaceLevel);
 
             // Log Verbosity Level
             this.logVerbosityOptions.Clear();
             this.logVerbosityOptions.Add(0);
             this.logVerbosityOptions.Add(1);
             this.logVerbosityOptions.Add(2);
-            this.SelectedVerbosity = userSettingService.GetUserSetting<int>(UserSettingConstants.Verbosity, typeof(int));
+            this.SelectedVerbosity = userSettingService.GetUserSetting<int>(UserSettingConstants.Verbosity);
 
             // Logs
             this.CopyLogToEncodeDirectory = userSettingService.GetUserSetting<bool>(UserSettingConstants.SaveLogWithVideo);
@@ -1485,7 +1540,7 @@ namespace HandBrakeWPF.ViewModels
             this.PreviewPicturesToScan.Add(50);
             this.PreviewPicturesToScan.Add(55);
             this.PreviewPicturesToScan.Add(60);
-            this.SelectedPreviewCount = this.userSettingService.GetUserSetting<int>(UserSettingConstants.PreviewScanCount, typeof(int));
+            this.SelectedPreviewCount = this.userSettingService.GetUserSetting<int>(UserSettingConstants.PreviewScanCount);
 
             // x264 step
             this.ConstantQualityGranularity.Clear();
@@ -1495,7 +1550,7 @@ namespace HandBrakeWPF.ViewModels
             this.SelectedGranulairty = userSettingService.GetUserSetting<double>(UserSettingConstants.X264Step).ToString("0.00", CultureInfo.InvariantCulture);
 
             // Min Title Length
-            this.MinLength = this.userSettingService.GetUserSetting<int>(UserSettingConstants.MinScanDuration, typeof(int));
+            this.MinLength = this.userSettingService.GetUserSetting<int>(UserSettingConstants.MinScanDuration);
 
             // Use dvdnav
             this.DisableLibdvdNav = userSettingService.GetUserSetting<bool>(UserSettingConstants.DisableLibDvdNav);
@@ -1506,7 +1561,7 @@ namespace HandBrakeWPF.ViewModels
         /// </summary>
         public void UpdateSettings()
         {
-            this.WhenDone = userSettingService.GetUserSetting<string>("WhenCompleteAction");
+            this.WhenDone = (WhenDone)this.userSettingService.GetUserSetting<int>(UserSettingConstants.WhenCompleteAction);
         }
 
         /// <summary>
@@ -1537,22 +1592,23 @@ namespace HandBrakeWPF.ViewModels
             /* General */
             this.userSettingService.SetUserSetting(UserSettingConstants.UpdateStatus, this.CheckForUpdates);
             this.userSettingService.SetUserSetting(UserSettingConstants.DaysBetweenUpdateCheck, this.CheckForUpdatesFrequency);
-            this.userSettingService.SetUserSetting(UserSettingConstants.WhenCompleteAction, this.WhenDone);
             this.userSettingService.SetUserSetting(UserSettingConstants.SendFileTo, this.SendFileToPath);
             this.userSettingService.SetUserSetting(UserSettingConstants.SendFile, this.SendFileAfterEncode);
             this.userSettingService.SetUserSetting(UserSettingConstants.SendFileToArgs, this.Arguments);
-            this.userSettingService.SetUserSetting(UserSettingConstants.ResetWhenDoneAction, this.ResetWhenDoneAction);
             this.userSettingService.SetUserSetting(UserSettingConstants.ShowStatusInTitleBar, this.ShowStatusInTitleBar);
             this.userSettingService.SetUserSetting(UserSettingConstants.ShowPreviewOnSummaryTab, this.ShowPreviewOnSummaryTab);
+            this.userSettingService.SetUserSetting(UserSettingConstants.UseDarkTheme, this.UseDarkTheme);
+            this.userSettingService.SetUserSetting(UserSettingConstants.UiLanguage, this.SelectedLanguage?.Culture);
+            this.userSettingService.SetUserSetting(UserSettingConstants.ShowAddAllToQueue, this.ShowAddAllToQueue);
+            this.userSettingService.SetUserSetting(UserSettingConstants.ShowAddSelectionToQueue, this.ShowAddSelectionToQueue);
+
+            /* When Done */
+            this.userSettingService.SetUserSetting(UserSettingConstants.WhenCompleteAction, (int)this.WhenDone);
+            this.userSettingService.SetUserSetting(UserSettingConstants.ResetWhenDoneAction, this.ResetWhenDoneAction);
+            this.userSettingService.SetUserSetting(UserSettingConstants.WhenDonePerformActionImmediately, this.WhenDonePerformActionImmediately);
             this.userSettingService.SetUserSetting(UserSettingConstants.PlaySoundWhenDone, this.PlaySoundWhenDone);
             this.userSettingService.SetUserSetting(UserSettingConstants.PlaySoundWhenQueueDone, this.PlaySoundWhenQueueDone);
             this.userSettingService.SetUserSetting(UserSettingConstants.WhenDoneAudioFile, this.WhenDoneAudioFileFullPath);
-            this.userSettingService.SetUserSetting(UserSettingConstants.UiLanguage, this.SelectedLanguage?.Culture);
-
-            /* Experiments */
-            this.userSettingService.SetUserSetting(UserSettingConstants.ShowQueueInline, this.ShowQueueInline);
-            this.userSettingService.SetUserSetting(UserSettingConstants.ShowExperimentalQueue, this.ShowExperimentalQueue);
-
 
             /* Output Files */
             this.userSettingService.SetUserSetting(UserSettingConstants.AutoNaming, this.AutomaticallyNameFiles);
@@ -1562,6 +1618,9 @@ namespace HandBrakeWPF.ViewModels
             this.userSettingService.SetUserSetting(UserSettingConstants.AutoNameRemoveUnderscore, this.RemoveUnderscores);
             this.userSettingService.SetUserSetting(UserSettingConstants.AutoNameTitleCase, this.ChangeToTitleCase);
             this.userSettingService.SetUserSetting(UserSettingConstants.RemovePunctuation, this.RemovePunctuation);
+            this.userSettingService.SetUserSetting(UserSettingConstants.FileOverwriteBehaviour, this.SelectedOverwriteBehaviour);
+            this.userSettingService.SetUserSetting(UserSettingConstants.AutonameFileCollisionBehaviour, this.SelectedCollisionBehaviour);
+            this.userSettingService.SetUserSetting(UserSettingConstants.AutonameFilePrePostString, this.PrePostFilenameText);
 
             /* Previews */
             this.userSettingService.SetUserSetting(UserSettingConstants.VLCPath, this.VLCPath);
@@ -1576,21 +1635,21 @@ namespace HandBrakeWPF.ViewModels
             this.userSettingService.SetUserSetting(UserSettingConstants.EnableNvencEncoder, this.EnableNvencEncoder);
 
             /* System and Logging */
-            userSettingService.SetUserSetting(UserSettingConstants.ProcessPriority, this.SelectedPriority);
-            userSettingService.SetUserSetting(UserSettingConstants.PreventSleep, this.PreventSleep);
-            userSettingService.SetUserSetting(UserSettingConstants.PauseOnLowDiskspace, this.PauseOnLowDiskspace);
-            userSettingService.SetUserSetting(UserSettingConstants.PauseOnLowDiskspaceLevel, this.PauseOnLowDiskspaceLevel);
-            userSettingService.SetUserSetting(UserSettingConstants.Verbosity, this.SelectedVerbosity);
-            userSettingService.SetUserSetting(UserSettingConstants.SaveLogWithVideo, this.CopyLogToEncodeDirectory);
-            userSettingService.SetUserSetting(UserSettingConstants.SaveLogToCopyDirectory, this.CopyLogToSepcficedLocation);
-            userSettingService.SetUserSetting(UserSettingConstants.SaveLogCopyDirectory, this.LogDirectory);
-            userSettingService.SetUserSetting(UserSettingConstants.ClearOldLogs, this.ClearOldOlgs);
+            this.userSettingService.SetUserSetting(UserSettingConstants.ProcessPriorityInt, this.SelectedPriority);
+            this.userSettingService.SetUserSetting(UserSettingConstants.PreventSleep, this.PreventSleep);
+            this.userSettingService.SetUserSetting(UserSettingConstants.PauseOnLowDiskspace, this.PauseOnLowDiskspace);
+            this.userSettingService.SetUserSetting(UserSettingConstants.PauseQueueOnLowDiskspaceLevel, this.PauseOnLowDiskspaceLevel);
+            this.userSettingService.SetUserSetting(UserSettingConstants.Verbosity, this.SelectedVerbosity);
+            this.userSettingService.SetUserSetting(UserSettingConstants.SaveLogWithVideo, this.CopyLogToEncodeDirectory);
+            this.userSettingService.SetUserSetting(UserSettingConstants.SaveLogToCopyDirectory, this.CopyLogToSepcficedLocation);
+            this.userSettingService.SetUserSetting(UserSettingConstants.SaveLogCopyDirectory, this.LogDirectory);
+            this.userSettingService.SetUserSetting(UserSettingConstants.ClearOldLogs, this.ClearOldOlgs);
 
             /* Advanced */
-            userSettingService.SetUserSetting(UserSettingConstants.MainWindowMinimize, this.MinimiseToTray);
-            userSettingService.SetUserSetting(UserSettingConstants.ClearCompletedFromQueue, this.ClearQueueOnEncodeCompleted);
-            userSettingService.SetUserSetting(UserSettingConstants.PreviewScanCount, this.SelectedPreviewCount);
-            userSettingService.SetUserSetting(UserSettingConstants.X264Step, double.Parse(this.SelectedGranulairty, CultureInfo.InvariantCulture));
+            this.userSettingService.SetUserSetting(UserSettingConstants.MainWindowMinimize, this.MinimiseToTray);
+            this.userSettingService.SetUserSetting(UserSettingConstants.ClearCompletedFromQueue, this.ClearQueueOnEncodeCompleted);
+            this.userSettingService.SetUserSetting(UserSettingConstants.PreviewScanCount, this.SelectedPreviewCount);
+            this.userSettingService.SetUserSetting(UserSettingConstants.X264Step, double.Parse(this.SelectedGranulairty, CultureInfo.InvariantCulture));
 
             int value;
             if (int.TryParse(this.MinLength.ToString(CultureInfo.InvariantCulture), out value))
@@ -1598,7 +1657,7 @@ namespace HandBrakeWPF.ViewModels
                 this.userSettingService.SetUserSetting(UserSettingConstants.MinScanDuration, value);
             }
 
-            userSettingService.SetUserSetting(UserSettingConstants.DisableLibDvdNav, this.DisableLibdvdNav);
+            this.userSettingService.SetUserSetting(UserSettingConstants.DisableLibDvdNav, this.DisableLibdvdNav);
         }
 
         /// <summary>
@@ -1676,6 +1735,11 @@ namespace HandBrakeWPF.ViewModels
         /// <returns>True if valid</returns>
         private bool IsValidAutonameFormat(string input, bool isSilent)
         {
+            if (string.IsNullOrEmpty(input))
+            {
+                return true;
+            }
+
             char[] invalidchars = Path.GetInvalidFileNameChars();
             Array.Sort(invalidchars);
             foreach (var characterToTest in input)
