@@ -11,15 +11,19 @@ namespace HandBrakeWPF.ViewModels
 {
     using System;
     using System.Collections.Generic;
+    using System.Collections.ObjectModel;
     using System.ComponentModel;
     using System.Diagnostics;
     using System.IO;
     using System.Linq;
+    using System.Runtime.CompilerServices;
     using System.Windows;
 
     using Caliburn.Micro;
 
     using HandBrakeWPF.EventArgs;
+    using HandBrakeWPF.Extensions;
+    using HandBrakeWPF.Model.Options;
     using HandBrakeWPF.Properties;
     using HandBrakeWPF.Services.Interfaces;
     using HandBrakeWPF.Services.Queue.Interfaces;
@@ -41,10 +45,10 @@ namespace HandBrakeWPF.ViewModels
 
         private readonly IErrorService errorService;
         private readonly IUserSettingService userSettingService;
-        private readonly IQueueProcessor queueProcessor;
+        private readonly IQueueService queueProcessor;
         private string jobStatus;
         private string jobsPending;
-        private string whenDoneAction;
+        private WhenDone whenDoneAction;
         private QueueTask selectedTask;
         private bool isQueueRunning;
         private double progressValue;
@@ -67,19 +71,19 @@ namespace HandBrakeWPF.ViewModels
         /// <param name="errorService">
         /// The Error Service 
         /// </param>
-        public QueueViewModel(IUserSettingService userSettingService, IQueueProcessor queueProcessor, IErrorService errorService)
+        public QueueViewModel(IUserSettingService userSettingService, IQueueService queueProcessor, IErrorService errorService)
         {
             this.userSettingService = userSettingService;
             this.queueProcessor = queueProcessor;
             this.errorService = errorService;
             this.Title = Resources.QueueViewModel_Queue;
             this.JobsPending = Resources.QueueViewModel_NoEncodesPending;
-            this.JobStatus = Resources.QueueViewModel_NoJobsPending;
+            this.JobStatus = string.Empty;
             this.SelectedItems = new BindingList<QueueTask>();
             this.DisplayName = "Queue";
             this.IsQueueRunning = false;
 
-            this.WhenDoneAction = this.userSettingService.GetUserSetting<string>(UserSettingConstants.WhenCompleteAction);
+            this.WhenDoneAction = (WhenDone)this.userSettingService.GetUserSetting<int>(UserSettingConstants.WhenCompleteAction);
         }
 
         #endregion
@@ -118,9 +122,12 @@ namespace HandBrakeWPF.ViewModels
             {
                 this.jobStatus = value;
                 this.NotifyOfPropertyChange(() => this.JobStatus);
+                this.NotifyOfPropertyChange(() => this.IsJobStatusVisible);
             }
         }
 
+        public bool IsJobStatusVisible => !string.IsNullOrEmpty(this.JobStatus)  && this.SelectedTask?.Status == QueueItemStatus.InProgress;
+
         /// <summary>
         /// Gets or sets JobsPending.
         /// </summary>
@@ -141,7 +148,7 @@ namespace HandBrakeWPF.ViewModels
         /// <summary>
         /// Gets or sets WhenDoneAction.
         /// </summary>
-        public string WhenDoneAction
+        public WhenDone WhenDoneAction
         {
             get
             {
@@ -158,7 +165,7 @@ namespace HandBrakeWPF.ViewModels
         /// <summary>
         /// Gets the queue tasks.
         /// </summary>
-        public BindingList<QueueTask> QueueTasks
+        public ObservableCollection<QueueTask> QueueTasks
         {
             get
             {
@@ -188,6 +195,8 @@ namespace HandBrakeWPF.ViewModels
                 this.NotifyOfPropertyChange(() => this.CanRetryJob);
                 this.NotifyOfPropertyChange(() => this.CanEditJob);
                 this.NotifyOfPropertyChange(() => this.CanRemoveJob);
+                this.NotifyOfPropertyChange(() => this.CanPerformActionOnSource);
+                this.NotifyOfPropertyChange(() => this.CanPlayFile);
                 this.NotifyOfPropertyChange(() => this.StatsVisible);
             }
         }
@@ -200,6 +209,12 @@ namespace HandBrakeWPF.ViewModels
 
         public bool CanRemoveJob => this.SelectedTask != null;
 
+        public bool CanPerformActionOnSource => this.SelectedTask != null;
+
+        public bool CanPlayFile =>
+            this.SelectedTask != null && this.SelectedTask.Task.Destination != null && 
+            this.SelectedTask.Status == QueueItemStatus.Completed && File.Exists(this.SelectedTask.Task.Destination);
+
         public double ProgressValue
         {
             get => this.progressValue;
@@ -233,16 +248,12 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        public bool IsNewQueueVisible { get; set; }
-
-        public bool IsInline { get; set; }
-
         public bool StatsVisible
         {
             get
             {
                 if (this.SelectedTask != null &&
-                    (this.selectedTask.Status == QueueItemStatus.Completed || this.selectedTask.Status == QueueItemStatus.Error))
+                    (this.selectedTask.Status == QueueItemStatus.Completed || this.selectedTask.Status == QueueItemStatus.Error || this.selectedTask.Status == QueueItemStatus.InProgress))
                 {
                     return true;
                 }
@@ -261,7 +272,7 @@ namespace HandBrakeWPF.ViewModels
         /// <param name="action">
         /// The action.
         /// </param>
-        public void WhenDone(string action)
+        public void WhenDone(int action)
         {
             this.WhenDone(action, true);
         }
@@ -275,9 +286,9 @@ namespace HandBrakeWPF.ViewModels
         /// <param name="saveChange">
         /// Save the change to the setting. Use false when updating UI.
         /// </param>
-        public void WhenDone(string action, bool saveChange)
+        public void WhenDone(int action, bool saveChange)
         {
-            this.WhenDoneAction = action;
+            this.WhenDoneAction = (WhenDone)action;
 
             if (saveChange)
             {
@@ -348,7 +359,6 @@ namespace HandBrakeWPF.ViewModels
         {
             this.queueProcessor.Pause();
 
-            this.JobStatus = Resources.QueueViewModel_QueuePending;
             this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
             this.IsQueueRunning = false;
 
@@ -372,6 +382,11 @@ namespace HandBrakeWPF.ViewModels
         /// </summary>
         public void RemoveSelectedJobs()
         {
+            if (this.SelectedItems.Count == 0)
+            {
+                return;
+            }
+
             MessageBoxResult result =
                   this.errorService.ShowMessageBox(
                       Resources.QueueViewModel_DelSelectedJobConfirmation,
@@ -444,10 +459,15 @@ namespace HandBrakeWPF.ViewModels
         /// </param>
         public void RetryJob(QueueTask task)
         {
+            if (task == null)
+            {
+                return;
+            }
+
             task.Status = QueueItemStatus.Waiting;
+            task.Statistics.Reset();
             this.queueProcessor.BackupQueue(null);
             this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
-            this.JobStatus = Resources.QueueViewModel_QueueReady;
             this.NotifyOfPropertyChange(() => this.CanRetryJob);
         }
 
@@ -465,23 +485,19 @@ namespace HandBrakeWPF.ViewModels
 
             var firstOrDefault = this.QueueTasks.FirstOrDefault(s => s.Status == QueueItemStatus.Waiting);
             if (firstOrDefault != null && !DriveUtilities.HasMinimumDiskSpace(firstOrDefault.Task.Destination,
-                    this.userSettingService.GetUserSetting<long>(UserSettingConstants.PauseOnLowDiskspaceLevel)))
+                    this.userSettingService.GetUserSetting<long>(UserSettingConstants.PauseQueueOnLowDiskspaceLevel)))
             {
                 this.errorService.ShowMessageBox(Resources.Main_LowDiskspace, Resources.Error, MessageBoxButton.OK, MessageBoxImage.Error);
                 return;
             }
 
-            this.JobStatus = Resources.QueueViewModel_QueueStarted;
             this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
             this.IsQueueRunning = true;
 
             this.queueProcessor.Start(userSettingService.GetUserSetting<bool>(UserSettingConstants.ClearCompletedFromQueue));
         }
 
-        /// <summary>
-        /// Export the Queue to a file.
-        /// </summary>
-        public void Export()
+        public void ExportCli()
         {
             SaveFileDialog dialog = new SaveFileDialog
             {
@@ -491,15 +507,28 @@ namespace HandBrakeWPF.ViewModels
                 AddExtension = true
             };
 
+            if (dialog.ShowDialog() == true)
+            {
+                this.queueProcessor.ExportCliJson(dialog.FileName);
+            }
+        }
+
+        public void Export()
+        {
+            SaveFileDialog dialog = new SaveFileDialog
+                                    {
+                                        Filter = "Json (*.json)|*.json",
+                                        OverwritePrompt = true,
+                                        DefaultExt = ".json",
+                                        AddExtension = true
+                                    };
+
             if (dialog.ShowDialog() == true)
             {
                 this.queueProcessor.ExportJson(dialog.FileName);
             }
         }
 
-        /// <summary>
-        /// Import a saved queue
-        /// </summary>
         public void Import()
         {
             OpenFileDialog dialog = new OpenFileDialog { Filter = "Json (*.json)|*.json", CheckFileExists = true };
@@ -536,6 +565,16 @@ namespace HandBrakeWPF.ViewModels
             mvm.EditQueueJob(task);
         }
 
+        public void OpenSourceDir()
+        {
+            this.OpenSourceDirectory(this.SelectedTask);
+        }
+
+        public void OpenDestDir()
+        {
+            this.OpenDestinationDirectory(this.SelectedTask);
+        }
+
         public void OpenSourceDirectory(QueueTask task)
         {
             if (task != null)
@@ -585,6 +624,41 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
+        public void PlayFile()
+        {
+            if (this.SelectedTask != null && this.SelectedTask.Task != null && File.Exists(this.SelectedTask.Task.Destination))
+            {
+                Process.Start(this.SelectedTask.Task.Destination);
+            }
+        }
+
+        public void MoveUp()
+        {
+            Dictionary<int, QueueTask> tasks = new Dictionary<int, QueueTask>();
+            foreach (var item in this.SelectedItems)
+            {
+                tasks.Add(this.QueueTasks.IndexOf(item), item);
+            }
+
+            foreach (var item in tasks.OrderBy(s => s.Key))
+            {
+                this.QueueTasks.MoveUp(item.Value);
+            }
+        }
+
+        public void MoveDown()
+        {
+            Dictionary<int, QueueTask> tasks = new Dictionary<int, QueueTask>();
+            foreach (var item in this.SelectedItems)
+            {
+                tasks.Add(this.QueueTasks.IndexOf(item), item);
+            }
+
+            foreach (var item in tasks.OrderByDescending(s => s.Key))
+            {
+                this.QueueTasks.MoveDown(item.Value);
+            }
+        }
 
         #endregion
 
@@ -615,7 +689,6 @@ namespace HandBrakeWPF.ViewModels
             this.queueProcessor.QueuePaused += this.QueueProcessor_QueuePaused;
 
             this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
-            this.JobStatus = Resources.QueueViewModel_QueueReady;
 
             base.OnActivate();
         }
@@ -644,16 +717,22 @@ namespace HandBrakeWPF.ViewModels
             {
                 if (!string.IsNullOrEmpty(directory))
                 {
+                    if (File.Exists(directory))
+                    {
+                        string argument = "/select, \"" + directory + "\"";
+                        Process.Start("explorer.exe", argument);
+                        return;
+                    }
+                    
                     if (!File.Exists(directory) && !directory.EndsWith("\\"))
                     {
-                        directory = directory + "\\";
+                        directory = Path.GetDirectoryName(directory) + "\\";
                     }
 
                     directory = Path.GetDirectoryName(directory);
                     if (directory != null && Directory.Exists(directory))
                     {
                         Process.Start(directory);
-
                     }
                 }
             }
@@ -765,7 +844,7 @@ namespace HandBrakeWPF.ViewModels
                 else
                 {
                     this.JobStatus =
-                        string.Format(Resources.MainViewModel_EncodeStatusChanged_StatusLabel,
+                        string.Format(Resources.QueueViewModel_EncodeStatusChanged_StatusLabel,
                             e.Task,
                             e.TaskCount,
                             e.PercentComplete,
@@ -794,13 +873,14 @@ namespace HandBrakeWPF.ViewModels
 
             if (!queueProcessor.IsProcessing)
             {
-                this.JobStatus = Resources.QueueViewModel_QueueNotRunning;
                 this.IsQueueRunning = false;
             }
 
             this.NotifyOfPropertyChange(() => this.CanRetryJob);
             this.NotifyOfPropertyChange(() => this.CanEditJob);
             this.NotifyOfPropertyChange(() => this.CanRemoveJob);
+            this.NotifyOfPropertyChange(() => this.CanPerformActionOnSource);
+            this.NotifyOfPropertyChange(() => this.CanPlayFile);
             this.NotifyOfPropertyChange(() => this.StatsVisible);
             this.HandleLogData();
         }
@@ -816,12 +896,13 @@ namespace HandBrakeWPF.ViewModels
         /// </param>
         private void queueProcessor_QueueCompleted(object sender, EventArgs e)
         {
-            this.JobStatus = Resources.QueueViewModel_QueueCompleted;
             this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
             this.IsQueueRunning = false;
             this.NotifyOfPropertyChange(() => this.SelectedTask);
             this.NotifyOfPropertyChange(() => this.StatsVisible);
             this.NotifyOfPropertyChange(() => this.CanRetryJob);
+
+            this.JobStatus = string.Empty;
         }
 
         /// <summary>
@@ -837,7 +918,7 @@ namespace HandBrakeWPF.ViewModels
         {
             if (!this.queueProcessor.IsProcessing)
             {
-                this.JobStatus = Resources.QueueViewModel_LastJobFinished;
+                this.JobStatus = string.Empty;
             }
         }
 
