@@ -14,6 +14,7 @@ namespace HandBrakeWPF.ViewModels
     using System.IO;
     using System.Linq;
     using System.Runtime.CompilerServices;
+    using System.Windows;
 
     using Caliburn.Micro;
 
@@ -22,9 +23,11 @@ namespace HandBrakeWPF.ViewModels
     using HandBrakeWPF.EventArgs;
     using HandBrakeWPF.Model.Subtitles;
     using HandBrakeWPF.Properties;
+    using HandBrakeWPF.Services.Interfaces;
     using HandBrakeWPF.Services.Presets.Model;
     using HandBrakeWPF.Services.Scan.Model;
     using HandBrakeWPF.ViewModels.Interfaces;
+    using HandBrakeWPF.Views;
 
     using Microsoft.Win32;
 
@@ -38,6 +41,7 @@ namespace HandBrakeWPF.ViewModels
     /// </summary>
     public class SubtitlesViewModel : ViewModelBase, ISubtitlesViewModel
     {
+        private readonly IErrorService errorService;
         private readonly IWindowManager windowManager;
 
         #region Constants and Fields
@@ -52,11 +56,15 @@ namespace HandBrakeWPF.ViewModels
         /// <summary>
         /// Initializes a new instance of the <see cref="HandBrakeWPF.ViewModels.SubtitlesViewModel"/> class.
         /// </summary>
+        /// <param name="errorService">
+        /// The Error Service
+        /// </param>
         /// <param name="windowManager">
         /// The window Manager.
         /// </param>
-        public SubtitlesViewModel(IWindowManager windowManager)
+        public SubtitlesViewModel(IErrorService errorService, IWindowManager windowManager)
         {
+            this.errorService = errorService;
             this.windowManager = windowManager;
             this.SubtitleDefaultsViewModel = new SubtitlesDefaultsViewModel();
             this.Task = new EncodeTask();
@@ -64,7 +72,7 @@ namespace HandBrakeWPF.ViewModels
             this.Langauges = LanguageUtilities.MapLanguages().Keys;
             this.CharacterCodes = CharCodesUtilities.GetCharacterCodes();
 
-            this.foreignAudioSearchTrack = new Subtitle { SubtitleType = SubtitleType.ForeignAudioSearch, Language = "Foreign Audio Search" };
+            this.foreignAudioSearchTrack = new Subtitle { SubtitleType = SubtitleType.ForeignAudioSearch, Language = Resources.SubtitleViewModel_ForeignAudioSearch };
             this.SourceTracks = new List<Subtitle> { this.foreignAudioSearchTrack };
         }
 
@@ -144,6 +152,14 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
+        public bool IsBurnableOnly
+        {
+            get
+            {
+                return this.Task.OutputFormat == OutputFormat.WebM;
+            }
+        }
+
         #endregion
 
         #region Public Methods
@@ -238,11 +254,11 @@ namespace HandBrakeWPF.ViewModels
         public void Import()
         {
             OpenFileDialog dialog = new OpenFileDialog
-                {
-                    Filter = "SRT files (*.srt)|*.srt",
-                    CheckFileExists = true,
-                    Multiselect = true
-                };
+            {
+                Filter = "Subtitle files (*.srt, *.ssa, *.ass)|*.srt;*.ssa;*.ass",
+                CheckFileExists = true,
+                Multiselect = true
+            };
 
             if (this.Task != null && this.Task.Source != null)
             {
@@ -438,8 +454,10 @@ namespace HandBrakeWPF.ViewModels
         /// </summary>
         public void ShowSubtitleDefaultsPanel()
         {
-            IPopupWindowViewModel popup = new PopupWindowViewModel(this.SubtitleDefaultsViewModel, Resources.Preset_SubtitleDefaults_Title, Resources.SubtitleView_SubtitleDefaultsDescription);
-            if (this.windowManager.ShowDialog(popup) == true)
+            SubtitlesDefaultsView view = new SubtitlesDefaultsView();
+            view.DataContext = this.SubtitleDefaultsViewModel;
+
+            if (view.ShowDialog() == true)
             {
                 this.OnTabStatusChanged(null);
             }
@@ -453,6 +471,26 @@ namespace HandBrakeWPF.ViewModels
             this.AutomaticSubtitleSelection();
         }
 
+        /// <summary>
+        /// Trigger a Notify Property Changed on the Task to force various UI elements to update.
+        /// </summary>
+        public void RefreshTask()
+        {
+            this.NotifyOfPropertyChange(() => this.Task);
+            this.NotifyOfPropertyChange(() => this.IsBurnableOnly);
+
+            if (this.IsBurnableOnly)
+            {
+                foreach (var subtitleTrack in this.Task.SubtitleTracks)
+                {
+                    if (subtitleTrack.Default)
+                    {
+                        subtitleTrack.Default = false;
+                    }
+                }
+            }
+        }
+
         #endregion
 
         #region Implemented Interfaces
@@ -553,6 +591,43 @@ namespace HandBrakeWPF.ViewModels
             this.AutomaticSubtitleSelection();
         }
 
+        /// <summary>
+        /// Checks the configuration of the subtitles and warns the user about any potential issues.
+        /// </summary>
+        public bool ValidateSubtitles()
+        {
+            var nonBurnedSubtitles = this.Task.SubtitleTracks.Where(subtitleTrack => !subtitleTrack.Burned).ToList();
+
+            if (nonBurnedSubtitles.Count > 0 && this.IsBurnableOnly)
+            {
+                MessageBoxResult result = this.errorService.ShowMessageBox(
+                    Resources.Subtitles_WebmSubtitleIncompatibilityError,
+                    Resources.Subtitles_WebmSubtitleIncompatibilityHeader,
+                    MessageBoxButton.OKCancel,
+                    MessageBoxImage.Warning);
+                if (result == MessageBoxResult.OK)
+                {
+                    foreach (var subtitleTrack in nonBurnedSubtitles)
+                    {
+                        if (!subtitleTrack.Burned)
+                        {
+                            this.Remove(subtitleTrack);
+                        }
+                    }
+                }
+                else if (result == MessageBoxResult.Cancel)
+                {
+                    return false;
+                }
+                else
+                {
+                    return false;
+                }
+            }
+
+            return true;
+        }
+
         #endregion
 
         #region Methods
@@ -640,10 +715,14 @@ namespace HandBrakeWPF.ViewModels
                 : LanguageUtilities.GetLanguageCodes(
                     this.SubtitleBehaviours.SelectedLangauges.ToArray());
 
-            List<Subtitle> availableTracks =
-                this.SourceTracks.Where(subtitle => iso6392Codes.Contains(subtitle.LanguageCodeClean)).ToList();
 
-           return availableTracks;
+            List<Subtitle> orderedSubtitles = new List<Subtitle>();
+            foreach (string code in iso6392Codes)
+            {
+                orderedSubtitles.AddRange(this.SourceTracks.Where(subtitle => subtitle.LanguageCodeClean == code ));
+            }
+
+            return orderedSubtitles;
         }
 
         /// <summary>
