@@ -15,6 +15,7 @@ namespace HandBrakeWPF.ViewModels
     using System.IO;
     using System.Runtime.ExceptionServices;
     using System.Text;
+    using System.Windows.Media;
     using System.Windows.Media.Imaging;
 
     using HandBrake.Interop.Interop;
@@ -23,6 +24,7 @@ namespace HandBrakeWPF.ViewModels
     using HandBrakeWPF.EventArgs;
     using HandBrakeWPF.Factories;
     using HandBrakeWPF.Helpers;
+    using HandBrakeWPF.Model.Options;
     using HandBrakeWPF.Properties;
     using HandBrakeWPF.Services.Encode.Model;
     using HandBrakeWPF.Services.Encode.Model.Models;
@@ -31,6 +33,7 @@ namespace HandBrakeWPF.ViewModels
     using HandBrakeWPF.Services.Scan.Interfaces;
     using HandBrakeWPF.Services.Scan.Model;
     using HandBrakeWPF.Utilities;
+    using HandBrakeWPF.ViewModelItems.Filters;
     using HandBrakeWPF.ViewModels.Interfaces;
 
     public class SummaryViewModel : ViewModelBase, ISummaryViewModel
@@ -109,6 +112,7 @@ namespace HandBrakeWPF.ViewModels
             {
                 return this.currentTitle;
             }
+
             set
             {
                 if (Equals(value, this.currentTitle)) return;
@@ -123,28 +127,37 @@ namespace HandBrakeWPF.ViewModels
             {
                 return new List<OutputFormat>
                        {
-                           OutputFormat.Mp4, OutputFormat.Mkv
+                           OutputFormat.Mp4, OutputFormat.Mkv, OutputFormat.WebM
                        };
             }
         }
 
         #region DisplayProperties
 
-        public BitmapImage PreviewImage { get; set; }
+        public BitmapSource PreviewImage { get; set; }
+
         public bool PreviewNotAvailable { get; set; }
+
         public int MaxWidth { get; set; }
+
         public int MaxHeight { get; set; }
 
         public string VideoTrackInfo { get; set; }
+
         public string AudioTrackInfo { get; set; }
+
         public string SubtitleTrackInfo { get; set; }
+
         public string ChapterInfo { get; set; }
+
         public string FiltersInfo { get; set; }
 
         public string DimensionInfo { get; set; }
+
         public string AspectInfo { get; set; }
 
         public bool IsPreviewInfoVisible { get; set; }
+
         public string PreviewInfo { get; set; }
 
         public bool IsPreviousPreviewControlVisible
@@ -153,6 +166,7 @@ namespace HandBrakeWPF.ViewModels
             {
                 return this.isPreviousPreviewControlVisible;
             }
+
             set
             {
                 if (value == this.isPreviousPreviewControlVisible) return;
@@ -167,6 +181,7 @@ namespace HandBrakeWPF.ViewModels
             {
                 return this.isNextPreviewControlVisible;
             }
+
             set
             {
                 if (value == this.isNextPreviewControlVisible) return;
@@ -181,6 +196,7 @@ namespace HandBrakeWPF.ViewModels
             {
                 return this.showPreview;
             }
+
             set
             {
                 if (value == this.showPreview) return;
@@ -211,8 +227,9 @@ namespace HandBrakeWPF.ViewModels
                     this.Task.OutputFormat = value;
                     this.NotifyOfPropertyChange(() => this.SelectedOutputFormat);
                     this.NotifyOfPropertyChange(() => this.Task.OutputFormat);
-                    this.NotifyOfPropertyChange(() => this.IsMkv);
+                    this.NotifyOfPropertyChange(() => this.IsMkvOrWebm);
                     this.SetExtension(string.Format(".{0}", this.Task.OutputFormat.ToString().ToLower()));
+                    this.UpdateDisplayedInfo(); // output format may coreced to another due to container incompatibility
 
                     this.OnOutputFormatChanged(new OutputFormatChangedEventArgs(null));
                     this.OnTabStatusChanged(null);
@@ -221,13 +238,13 @@ namespace HandBrakeWPF.ViewModels
         }
 
         /// <summary>
-        /// Gets or sets a value indicating whether IsMkv.
+        /// Gets or sets a value indicating whether IsMkvOrWebm.
         /// </summary>
-        public bool IsMkv
+        public bool IsMkvOrWebm
         {
             get
             {
-                return this.SelectedOutputFormat == OutputFormat.Mkv;
+                return this.SelectedOutputFormat == OutputFormat.Mkv || this.SelectedOutputFormat == OutputFormat.WebM;
             }
         }
 
@@ -316,8 +333,8 @@ namespace HandBrakeWPF.ViewModels
             this.UpdateDisplayedInfo();
 
             this.NotifyOfPropertyChange(() => this.SelectedOutputFormat);
-            this.NotifyOfPropertyChange(() => this.IsMkv);
-
+            this.NotifyOfPropertyChange(() => this.IsMkvOrWebm);
+ 
             this.NotifyOfPropertyChange(() => this.OptimizeMP4);
             this.NotifyOfPropertyChange(() => this.IPod5GSupport);
             this.NotifyOfPropertyChange(() => this.AlignAVStart);
@@ -367,7 +384,7 @@ namespace HandBrakeWPF.ViewModels
 
         public void NextPreview()
         {
-            int maxPreview = this.userSettingService.GetUserSetting<int>(UserSettingConstants.PreviewScanCount, typeof(int));
+            int maxPreview = this.userSettingService.GetUserSetting<int>(UserSettingConstants.PreviewScanCount);
             if (this.selectedPreview == maxPreview)
             {
                 return;
@@ -383,7 +400,7 @@ namespace HandBrakeWPF.ViewModels
 
         public void PreviousPreview()
         {
-            int maxPreview = this.userSettingService.GetUserSetting<int>(UserSettingConstants.PreviewScanCount, typeof(int));
+            int maxPreview = this.userSettingService.GetUserSetting<int>(UserSettingConstants.PreviewScanCount);
             if (this.selectedPreview <= 1)
             {
                 return;
@@ -408,7 +425,7 @@ namespace HandBrakeWPF.ViewModels
                 this.IsPreviousPreviewControlVisible = false;
             }
 
-            if (this.selectedPreview < this.userSettingService.GetUserSetting<int>(UserSettingConstants.PreviewScanCount, typeof(int)))
+            if (this.selectedPreview < this.userSettingService.GetUserSetting<int>(UserSettingConstants.PreviewScanCount))
             {
                 this.IsNextPreviewControlVisible = true;
             }
@@ -439,29 +456,29 @@ namespace HandBrakeWPF.ViewModels
             // Make sure the output extension is set correctly based on the users preferences and selection.
             if (newExtension == ".mp4" || newExtension == ".m4v")
             {
-                switch (this.userSettingService.GetUserSetting<int>(UserSettingConstants.UseM4v, typeof(int)))
+                switch ((Mp4Behaviour)this.userSettingService.GetUserSetting<int>(UserSettingConstants.UseM4v))
                 {
-                    case 0: // Auto
+                    case Mp4Behaviour.Auto: // Auto
                         newExtension = MP4Helper.RequiresM4v(this.Task) ? ".m4v" : ".mp4";
                         break;
-                    case 1: // MP4
+                    case Mp4Behaviour.MP4: // MP4
                         newExtension = ".mp4";
                         break;
-                    case 2: // M4v
+                    case Mp4Behaviour.M4V: // M4v
                         newExtension = ".m4v";
                         break;
                 }
             }
 
             // Now disable controls that are not required. The Following are for MP4 only!
-            if (newExtension == ".mkv")
+            if (newExtension == ".mkv" || newExtension == ".webm")
             {
                 this.OptimizeMP4 = false;
                 this.IPod5GSupport = false;
                 this.AlignAVStart = false;
             }
 
-            this.NotifyOfPropertyChange(() => this.IsMkv);
+            this.NotifyOfPropertyChange(() => this.IsMkvOrWebm);
 
             // Update The browse file extension display
             if (Path.HasExtension(newExtension))
@@ -497,7 +514,7 @@ namespace HandBrakeWPF.ViewModels
             this.FiltersInfo = this.GetFilterDescription();
             this.NotifyOfPropertyChange(() => this.FiltersInfo);
 
-            // Picutre Section
+            // Picture Section
             this.DimensionInfo = string.Format("{0}x{1} {2}, {3}x{4} {5}", this.Task.Width, this.Task.Height, Resources.SummaryView_storage, this.Task.DisplayWidth, this.Task.Height, Resources.SummaryView_display);
             this.NotifyOfPropertyChange(() => this.DimensionInfo);
 
@@ -505,7 +522,7 @@ namespace HandBrakeWPF.ViewModels
             this.NotifyOfPropertyChange(() => this.AspectInfo);
 
             // Preview
-            this.PreviewInfo = string.Format(Resources.SummaryView_PreviewInfo, this.selectedPreview, this.userSettingService.GetUserSetting<int>(UserSettingConstants.PreviewScanCount, typeof(int)));
+            this.PreviewInfo = string.Format(Resources.SummaryView_PreviewInfo, this.selectedPreview, this.userSettingService.GetUserSetting<int>(UserSettingConstants.PreviewScanCount));
             this.NotifyOfPropertyChange(() => this.PreviewInfo);
 
             this.ShowPreview = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.ShowPreviewOnSummaryTab);
@@ -540,7 +557,7 @@ namespace HandBrakeWPF.ViewModels
                 filters.Add(this.Task.Sharpen.ToString());
             }
 
-            if (this.Task.Deblock > 4)
+            if (this.Task.DeblockPreset != null && this.Task.DeblockPreset.Key != DeblockFilter.Off)
             {
                 filters.Add(Resources.SummaryView_Deblock);
             }
@@ -666,7 +683,7 @@ namespace HandBrakeWPF.ViewModels
                 return;
             }
 
-            BitmapImage image = null;
+            BitmapSource image = null;
             try
             {
                 image = this.scanService.GetPreview(this.Task, this.selectedPreview - 1, HBConfigurationFactory.Create()); 
@@ -679,6 +696,8 @@ namespace HandBrakeWPF.ViewModels
 
             if (image != null)
             {
+                image = BitmapHelpers.CreateTransformedBitmap(image, this.task.Rotation, this.task.FlipVideo);
+
                 this.PreviewNotAvailable = false;
                 this.PreviewImage = image;
                 this.MaxWidth = (int)image.Width;
