@@ -110,51 +110,6 @@ namespace HandBrakeWPF.ViewModels
         /// </summary>
         public EncodeTask Task { get; set; }
 
-        /// <summary>
-        /// Gets a value indicating whether show advanced tab.
-        /// </summary>
-        public bool IsAdvancedTabOptionEnabled
-        {
-            get
-            {
-                bool showAdvTabSetting = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.ShowAdvancedTab);
-                if (!showAdvTabSetting)
-                {
-                    this.UseAdvancedTab = false;
-                }
-
-                if (this.SelectedVideoEncoder != VideoEncoder.X264 && this.SelectedVideoEncoder != VideoEncoder.X264_10)
-                {
-                    this.UseAdvancedTab = false;
-                    return false;
-                }
-
-                return showAdvTabSetting;
-            }
-        }
-
-        /// <summary>
-        /// Gets or sets a value indicating whether use video tab.
-        /// </summary>
-        public bool UseAdvancedTab
-        {
-            get
-            {
-                return this.Task.ShowAdvancedTab;
-            }
-            set
-            {
-                if (!Equals(value, this.Task.ShowAdvancedTab))
-                {
-                    // Set the Advanced Tab up with the current settings, if we can.
-                    this.Task.AdvancedEncoderOptions = value ? this.GetActualx264Query() : string.Empty;
-                    this.Task.ShowAdvancedTab = value;
-
-                    this.NotifyOfPropertyChange(() => this.UseAdvancedTab);
-                }
-            }
-        }
-
         /// <summary>
         /// Gets Framerates.
         /// </summary>
@@ -476,8 +431,21 @@ namespace HandBrakeWPF.ViewModels
         {
             get
             {
-                return this.SelectedVideoEncoder == VideoEncoder.X264 || this.SelectedVideoEncoder == VideoEncoder.X264_10 || this.SelectedVideoEncoder == VideoEncoder.X265
-                       || this.SelectedVideoEncoder == VideoEncoder.X265_10 || this.SelectedVideoEncoder == VideoEncoder.X265_12 ? "RF" : "QP";
+                if (this.SelectedVideoEncoder == VideoEncoder.X264 || this.SelectedVideoEncoder == VideoEncoder.X264_10
+                                                                   || this.SelectedVideoEncoder == VideoEncoder.X265
+                                                                   || this.SelectedVideoEncoder == VideoEncoder.X265_10
+                                                                   || this.SelectedVideoEncoder == VideoEncoder.X265_12)
+                {
+                    return "RF";
+                }
+
+                if (this.SelectedVideoEncoder == VideoEncoder.NvencH264
+                    || this.SelectedVideoEncoder == VideoEncoder.NvencH265)
+                {
+                    return string.Empty;
+                }
+
+                return "QP";
             }
         }
 
@@ -655,6 +623,8 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
+        public bool DisplayFastDecode { get; set; }
+
         /// <summary>
         /// Gets or sets a value indicating whether display level control.
         /// </summary>
@@ -706,10 +676,6 @@ namespace HandBrakeWPF.ViewModels
             }
             set
             {
-                if (value.Equals(this.fastDecode))
-                {
-                    return;
-                }
                 this.fastDecode = value;
 
                 // Update the encode task
@@ -816,7 +782,7 @@ namespace HandBrakeWPF.ViewModels
                     this.Task.VideoTunes.Add(value);
                 }
 
-                if (hasFastDecode)
+                if ((this.SelectedVideoEncoder == VideoEncoder.X264 || this.SelectedVideoEncoder == VideoEncoder.X264_10) && hasFastDecode)
                 {
                     this.Task.VideoTunes.Add(VideoTune.FastDecode);
                 }
@@ -998,14 +964,22 @@ namespace HandBrakeWPF.ViewModels
                     this.VideoLevel = preset.Task.VideoLevel != null ? preset.Task.VideoLevel.Clone() : this.VideoLevels.FirstOrDefault();
                     this.VideoProfile = preset.Task.VideoProfile != null ? preset.Task.VideoProfile.Clone() : this.VideoProfiles.FirstOrDefault();
                     this.VideoPresetValue = preset.Task.VideoPreset != null ? this.VideoPresets.IndexOf(preset.Task.VideoPreset) : 0;
-                    this.FastDecode = preset.Task.VideoTunes != null && preset.Task.VideoTunes.Contains(VideoTune.FastDecode);
-                    this.VideoTune = (preset.Task.VideoTunes != null && preset.Task.VideoTunes.Any() ? preset.Task.VideoTunes.FirstOrDefault(t => !Equals(t, VideoTune.FastDecode)) : this.VideoTunes.FirstOrDefault())
-                                     ?? VideoTune.None;
+
+                    if (preset.Task.VideoEncoder == VideoEncoder.X265 || preset.Task.VideoEncoder == VideoEncoder.X265_10 || preset.Task.VideoEncoder == VideoEncoder.X265_12)
+                    {
+                        this.FastDecode = false;
+                        this.VideoTune = (preset.Task.VideoTunes != null && preset.Task.VideoTunes.Any() ? preset.Task.VideoTunes.FirstOrDefault() : this.VideoTunes.FirstOrDefault()) ?? VideoTune.None;
+                    }
+                    else
+                    {
+                        this.FastDecode = preset.Task.VideoTunes != null && preset.Task.VideoTunes.Contains(VideoTune.FastDecode);
+                        this.VideoTune = (preset.Task.VideoTunes != null && preset.Task.VideoTunes.Any() ? preset.Task.VideoTunes.FirstOrDefault(t => !Equals(t, VideoTune.FastDecode)) : this.VideoTunes.FirstOrDefault())
+                                         ?? VideoTune.None;
+                    }
                 }
             }
 
             this.ExtraArguments = preset.Task.ExtraAdvancedArguments;
-            this.UseAdvancedTab = this.IsAdvancedTabOptionEnabled && preset.Task.ShowAdvancedTab;
         }
 
         /// <summary>
@@ -1161,10 +1135,17 @@ namespace HandBrakeWPF.ViewModels
         {
             this.NotifyOfPropertyChange(() => this.Task);
 
-            if ((Task.OutputFormat == OutputFormat.Mp4) && this.SelectedVideoEncoder == VideoEncoder.Theora)
+            VideoEncoder[] allowableWebmEncoders = { VideoEncoder.VP8, VideoEncoder.VP9 };
+
+            if ((Task.OutputFormat == OutputFormat.Mp4) && (this.SelectedVideoEncoder == VideoEncoder.Theora || allowableWebmEncoders.Contains(this.SelectedVideoEncoder)))
             {
                 this.SelectedVideoEncoder = VideoEncoder.X264;
             }
+
+            if ((Task.OutputFormat == OutputFormat.WebM) && !allowableWebmEncoders.Contains(this.SelectedVideoEncoder))
+            {
+                this.SelectedVideoEncoder = VideoEncoder.VP8;
+            }
         }
 
         /// <summary>
@@ -1175,25 +1156,6 @@ namespace HandBrakeWPF.ViewModels
             Clipboard.SetDataObject(this.SelectedVideoEncoder == VideoEncoder.X264 || this.SelectedVideoEncoder == VideoEncoder.X264_10 ? this.GetActualx264Query() : this.ExtraArguments);
         }
 
-        public void ToggleAdvancedTab()
-        {
-            if (!this.userSettingService.GetUserSetting<bool>(UserSettingConstants.ShowAdvancedTab))
-            {
-                this.errorService.ShowMessageBox(
-                    "The 'Advanced' tab is no longer supported and will be removed in an upcoming release. We strongly recommend using the video tab instead.",
-                    "Advanced Tab Deprecated",
-                    MessageBoxButton.OK,
-                    MessageBoxImage.Information);
-                this.userSettingService.SetUserSetting(UserSettingConstants.ShowAdvancedTab, true);
-                this.UseAdvancedTab = true;
-            }
-            else
-            {
-                this.userSettingService.SetUserSetting(UserSettingConstants.ShowAdvancedTab, false);
-                this.UseAdvancedTab = false;
-            }
-        }
-
         #endregion
 
         protected virtual void OnTabStatusChanged(TabStatusEventArgs e)
@@ -1313,9 +1275,8 @@ namespace HandBrakeWPF.ViewModels
         /// </param>
         private void UserSettingServiceSettingChanged(object sender, SettingChangedEventArgs e)
         {
-            if (e.Key == UserSettingConstants.ShowAdvancedTab)
+            if (e.Key == UserSettingConstants.EnableVceEncoder || e.Key == UserSettingConstants.EnableNvencEncoder || e.Key == UserSettingConstants.EnableQuickSyncEncoding)
             {
-                this.NotifyOfPropertyChange(() => this.IsAdvancedTabOptionEnabled);
                 this.NotifyOfPropertyChange(() => this.VideoEncoders);
             }
         }
@@ -1400,11 +1361,6 @@ namespace HandBrakeWPF.ViewModels
         /// </param>
         private void HandleEncoderChange(VideoEncoder selectedEncoder)
         {
-            if (selectedEncoder != VideoEncoder.X264)
-            {
-                this.UseAdvancedTab = false;
-            }
-
             HBVideoEncoder encoder = HandBrakeEncoderHelpers.VideoEncoders.FirstOrDefault(s => s.ShortName == EnumHelper<VideoEncoder>.GetShortName(selectedEncoder));
             if (encoder != null)
             {
@@ -1430,10 +1386,12 @@ namespace HandBrakeWPF.ViewModels
                     this.VideoTunes.Add(VideoTune.None);
                     foreach (var item in encoder.Tunes)
                     {
-                        if (item != VideoTune.FastDecode.ShortName)
+                        if (item == VideoTune.FastDecode.ShortName && (selectedEncoder == VideoEncoder.X264 || selectedEncoder == VideoEncoder.X264_10))
                         {
-                            this.VideoTunes.Add(new VideoTune(item, item));
+                            continue;
                         }
+
+                        this.VideoTunes.Add(new VideoTune(item, item));
                     }
                     this.FastDecode = false;
                     this.VideoTune = VideoTune.None;
@@ -1485,19 +1443,10 @@ namespace HandBrakeWPF.ViewModels
                 }
             }
 
-            // Tell the Advanced Panel off the change
-            IX264ViewModel advancedViewModel = IoC.Get<IX264ViewModel>();
-            advancedViewModel.SetEncoder(this.Task.VideoEncoder);
-
             // Update the Quality Slider. Make sure the bounds are up to date with the users settings.
             this.SetQualitySliderBounds();
 
             // Update control display
-            this.UseAdvancedTab = selectedEncoder != VideoEncoder.QuickSync && selectedEncoder != VideoEncoder.QuickSyncH265 && selectedEncoder != VideoEncoder.QuickSyncH26510b
-                               && selectedEncoder != VideoEncoder.VceH264 && selectedEncoder != VideoEncoder.VceH265
-                               && selectedEncoder != VideoEncoder.NvencH264 && selectedEncoder != VideoEncoder.NvencH265
-                               && this.UseAdvancedTab;
-
             this.DisplayOptimiseOptions = this.SelectedVideoEncoder == VideoEncoder.X264 || this.SelectedVideoEncoder == VideoEncoder.X264_10 ||
                                           this.SelectedVideoEncoder == VideoEncoder.X265 || this.SelectedVideoEncoder == VideoEncoder.X265_10 || this.SelectedVideoEncoder == VideoEncoder.X265_12 ||
                                           this.SelectedVideoEncoder == VideoEncoder.QuickSync || this.SelectedVideoEncoder == VideoEncoder.QuickSyncH265 || this.SelectedVideoEncoder == VideoEncoder.QuickSyncH26510b ||
@@ -1511,11 +1460,20 @@ namespace HandBrakeWPF.ViewModels
             this.DisplayTuneControls = this.SelectedVideoEncoder == VideoEncoder.X264 || this.SelectedVideoEncoder == VideoEncoder.X264_10 || 
                                        this.SelectedVideoEncoder == VideoEncoder.X265 || this.SelectedVideoEncoder == VideoEncoder.X265_10 || this.SelectedVideoEncoder == VideoEncoder.X265_12;
 
-            this.DisplayLevelControl = this.SelectedVideoEncoder == VideoEncoder.X264 || this.SelectedVideoEncoder == VideoEncoder.X264_10 || 
+            this.DisplayLevelControl = this.SelectedVideoEncoder == VideoEncoder.X264 || this.SelectedVideoEncoder == VideoEncoder.X264_10 ||
+                                       this.SelectedVideoEncoder == VideoEncoder.X265 || this.SelectedVideoEncoder == VideoEncoder.X265_10 || this.SelectedVideoEncoder == VideoEncoder.X265_12 ||
                                        this.SelectedVideoEncoder == VideoEncoder.QuickSync || this.SelectedVideoEncoder == VideoEncoder.QuickSyncH265 || this.SelectedVideoEncoder == VideoEncoder.QuickSyncH26510b ||
                                        this.SelectedVideoEncoder == VideoEncoder.VceH264 || this.SelectedVideoEncoder == VideoEncoder.VceH265 ||
                                        this.SelectedVideoEncoder == VideoEncoder.NvencH264 || this.SelectedVideoEncoder == VideoEncoder.NvencH265;
 
+            this.DisplayFastDecode = this.SelectedVideoEncoder == VideoEncoder.X264 || this.SelectedVideoEncoder == VideoEncoder.X264_10;
+            this.NotifyOfPropertyChange(() => this.DisplayFastDecode);
+
+            if (!this.DisplayFastDecode)
+            {
+                this.FastDecode = false;
+            }
+
             this.DisplayProfileControl = this.SelectedVideoEncoder == VideoEncoder.X264
                                          || this.SelectedVideoEncoder == VideoEncoder.X264_10
                                          || this.SelectedVideoEncoder == VideoEncoder.X265
@@ -1531,7 +1489,6 @@ namespace HandBrakeWPF.ViewModels
 
             // Refresh Display
             this.NotifyOfPropertyChange(() => this.Rfqp);
-            this.NotifyOfPropertyChange(() => this.IsAdvancedTabOptionEnabled);
             this.NotifyOfPropertyChange(() => this.HighQualityLabel);
             this.NotifyOfPropertyChange(() => this.IsTwoPassEnabled);
             this.NotifyOfPropertyChange(() => this.DisplayTwoPass);
@@ -1543,7 +1500,6 @@ namespace HandBrakeWPF.ViewModels
                 this.TurboFirstPass = false;
                 this.Task.Framerate = null;
                 this.NotifyOfPropertyChange(() => this.SelectedFramerate);
-                this.UseAdvancedTab = false;
             }
 
             if (selectedEncoder == VideoEncoder.NvencH264 || selectedEncoder == VideoEncoder.NvencH265 
